@@ -3,7 +3,7 @@
  ** Written by Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: iconv.c 3774 2007-09-26 00:18:39Z regit $
+ ** $Id: iconv.c 4327 2008-01-18 23:20:43Z haypo $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -70,7 +70,7 @@ char *nu_client_to_utf8(const char *inbuf, char *from_charset)
 	outbufleft = outbuflen - 1;	/* -1 because we keep last byte for nul byte */
 	targetbuf = outbuf;
 	ret =
-	    iconv(ctx, (char **) &inbuf, &inlen, &targetbuf, &outbufleft);
+	    iconv(ctx, (const char **) &inbuf, &inlen, &targetbuf, &outbufleft);
 	real_outlen = targetbuf - outbuf;
 
 	/* is buffer too small? */
@@ -98,7 +98,7 @@ char *nu_client_to_utf8(const char *inbuf, char *from_charset)
 			outbufleft = outbuflen - real_outlen - 1;	/* -1 because we keep last byte for nul byte */
 			targetbuf = outbuf + real_outlen;
 			ret =
-			    iconv(ctx, (char **) &inbuf, &inlen,
+			    iconv(ctx, (const char **) &inbuf, &inlen,
 				  &targetbuf, &outbufleft);
 			real_outlen = targetbuf - outbuf;
 		}
