@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: internal.c 4193 2007-12-28 10:29:54Z regit $
+ ** $Id: internal.c 4475 2008-02-16 23:15:45Z lds $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -21,8 +21,15 @@
  */
 
 #include "nufw_source.h"
+
+#ifdef FREEBSD
+#include "ipv6.h"
+#include "nuclient.h"
+#else
 #include "nuclient.h"
 #include "ipv6.h"
+#endif
+
 #include <sasl/saslutil.h>
 #include <pthread.h>
 #include <stdarg.h>		/* va_list, va_start, ... */
@@ -495,6 +502,9 @@ static int nu_get_userdatas(void *context __attribute__ ((unused)),
 			char *utf8name;
 #endif
 			char *givenuser=session->username_callback();
+			if (givenuser == NULL){
+				return SASL_FAIL;
+			}
 #if USE_UTF8
 			utf8name = nu_client_to_utf8(givenuser, nu_locale_charset);
 			free(givenuser);
@@ -725,6 +735,7 @@ int certificate_check(nuauth_session_t *session)
 
 	if (get_first_x509_cert_from_tls_session(session->tls, &cert)
 			!= SASL_OK) {
+		printf("TLS error: Cannot get first x509 cert from TLS session\n");
 		return SASL_BADPARAM;
 	}
 
@@ -734,11 +745,13 @@ int certificate_check(nuauth_session_t *session)
 	/* verify date */
 	if (expiration_time < time(NULL)) {
 		gnutls_x509_crt_deinit(cert);
+		printf("TLS error: Certificate expired\n");
 		return SASL_EXPIRED;
 	}
 
 	if (activation_time > time(NULL)) {
 		gnutls_x509_crt_deinit(cert);
+		printf("TLS error: Certificate not yet activated\n");
 		return SASL_DISABLED;
 	}
 
@@ -752,6 +765,7 @@ int certificate_check(nuauth_session_t *session)
 		}
 		if (strcmp(dn, session->nuauth_cert_dn)) {
 			gnutls_x509_crt_deinit(cert);
+			printf("TLS error: DN does not match the certificate DN\n");
 			return SASL_DISABLED;
 		}
 	}
