@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: libnuclient.c 4278 2008-01-08 17:31:23Z lds $
+ ** $Id: libnuclient.c 4544 2008-03-06 12:51:03Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -26,10 +26,10 @@
  */
 
 /*! \file libnuclient.c
-  \brief Main file for libnuclient
-
-  It contains all the exported functions
-  */
+ * \brief Main file for libnuclient
+ *
+ * It contains all the exported functions
+ * */
 
 /**
  * Use gcry_malloc_secure() to disallow a memory page
@@ -158,6 +158,8 @@ int nu_client_global_init(nuclient_error_t * err)
 		exit(EXIT_FAILURE);
 	}
 
+	load_sys_config();
+
 	return 1;
 }
 
@@ -232,12 +234,12 @@ int check_key_perms(const char* filename)
 	if (stat(filename, &infos) != 0) {
 		return 0;
 	}
-	
+
 	/* Check it's owned by the current user */
 	if (infos.st_mode & S_IRGRP || infos.st_mode & S_IROTH) {
 		return 0;
 	}
-	
+
 	return 1;
 }
 
@@ -360,9 +362,9 @@ int nu_client_setup_tls(nuauth_session_t * session,
 		}
 		session->need_ca_verif = 1;
 	}
- 
- 	if (keyfile && !check_key_perms(keyfile)) {
-		printf("Private key have too open permissions.\n");
+
+	if (keyfile && !check_key_perms(keyfile)) {
+		printf("Private key has too open permissions.\n");
 		SET_ERROR(err, INTERNAL_ERROR, FILE_ACCESS_ERR);
 		return 0;
 	}
@@ -500,10 +502,6 @@ nuauth_session_t *_nu_client_new(nuclient_error_t * err)
 	session->timestamp_last_sent = time(NULL);
 	session->need_set_cred = 1;
 	session->need_ca_verif = 0;
-	session->default_hostname = NULL;
-	session->default_port = NULL;
-
-	load_sys_config(session);
 
 	/* create session mutex */
 	pthread_mutex_init(&(session->mutex), NULL);
