@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: nuclient.h 4235 2008-01-04 23:30:00Z regit $
+ ** $Id: nuclient.h 4462 2008-02-14 16:26:51Z lds $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -35,10 +35,6 @@ extern "C" {
 #   error "nuclient.h have to be included before <features.h>"
 #endif
 
-#ifndef FREEBSD
-#include <features.h>
-#endif
-
 #include <arpa/inet.h>
 #include <assert.h>
 #include <ctype.h>
@@ -228,9 +224,6 @@ typedef struct {
 	/** Do we need to check the CA certificate */
 	unsigned char need_ca_verif;
 
-	/** Connection to nuauth informations */
-	char* default_hostname;
-	char* default_port;
 
 } nuauth_session_t;
 
@@ -296,6 +289,10 @@ void nu_client_set_username(nuauth_session_t *session,
 void nu_client_set_password(nuauth_session_t *session,
 		const char *password);
 
+const char* nu_client_default_hostname();
+	
+const char* nu_client_default_port();
+
 void nu_client_set_debug(nuauth_session_t * session, unsigned char enabled);
 void nu_client_set_verbose(nuauth_session_t * session,
 		unsigned char enabled);
