@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@inl.fr>
  ** INL http://www.inl.fr
  **
- ** $Id: tcptable.c 4121 2007-12-18 13:07:50Z haypo $
+ ** $Id: tcptable.c 4393 2008-01-29 13:22:28Z lds $
  **
  **
  ** This program is free software; you can redistribute it and/or modify
@@ -20,13 +20,20 @@
  ** along with this program; if not, write to the Free Software
  ** Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  */
-#include "client.h"
-#include "nuclient.h"
+
+#include <config.h>
+#ifdef FREEBSD
+#include "ipv6.h"
 #include "libnuclient.h"
+#else
+#include "libnuclient.h"
+#include "ipv6.h"
+#endif
+
+#include "client.h"
 #include "proto.h"
 #include <pthread.h>
 #include <inttypes.h>
-#include <ipv6.h>
 #define USE_JHASH3
 #include <jhash.h>
 #ifdef FREEBSD
@@ -315,10 +322,10 @@ int tcptable_read(nuauth_session_t * session, conntable_t * ct)
 			continue;
 
 		uint32_to_ipv6(inp->inp_laddr.s_addr, &c.ip_src);
-		c.port_src = inp->inp_lport;
+		c.port_src = ntohs(inp->inp_lport);
 
 		uint32_to_ipv6(inp->inp_faddr.s_addr, &c.ip_dst);
-		c.port_dst = inp->inp_fport;
+		c.port_dst = ntohs(inp->inp_fport);
 		c.protocol = IPPROTO_TCP;
 
 		tcptable_add(ct, &c);
