@@ -1,10 +1,10 @@
 /*
- ** Copyright 2004-2007 - INL
+ ** Copyright 2004-2008 - INL
  ** Written by Eric Leblond <eric.leblond@inl.fr>
  **            Vincent Deffontaines <vincent@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: nutcpc.c 4039 2007-12-05 16:39:02Z lds $
+ ** $Id: nutcpc.c 4607 2008-04-03 12:58:08Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -31,7 +31,9 @@
 #include <signal.h>
 #include "proto.h"
 #include "security.h"
-#define NUTCPC_VERSION PACKAGE_VERSION " $Revision: 4039 $"
+#define NUTCPC_VERSION PACKAGE_VERSION " $Revision: 4607 $"
+
+#define RETURN_NO_LOG return
 
 #ifdef FREEBSD
 #include <readpassphrase.h>
@@ -202,8 +204,10 @@ ssize_t getline(char **lineptr, size_t * n, FILE * stream)
 	/* buffer need to grow up? */
 	if (len >= *n) {
 		char *tmp = realloc(*lineptr, len + 1);
-		if (tmp == NULL)
+		if (tmp == NULL) {
+			printf("Not enough memory\n");
 			return -1;
+		}
 		*lineptr = tmp;
 		*n = len + 1;
 	}
@@ -280,10 +284,11 @@ char *get_password()
 		fprintf(stderr, "unable to read passphrase");
 	}
 #else
-	printf(question);
+	printf("%s", question);
 	ret = my_getpass(&new_pass, &password_size);
 	if (ret < 0) {
 		free(new_pass);
+		printf("Problem when getting password\n");
 		return NULL;
 	}
 #endif
@@ -307,6 +312,7 @@ char *get_username()
 	nread = getline(&username, &username_size, stdin);
 	if (nread < 0) {
 		free(username);
+		printf("Problem when reading username\n");
 		return NULL;
 	}
 	if (0 < nread && username[nread - 1] == '\n') {
@@ -346,7 +352,7 @@ static void usage(void)
 
 void process_hup(int signum)
 {
-  forced_reconnect = 1;
+	forced_reconnect = 1;
 }
 
 /**
@@ -362,24 +368,22 @@ void install_signals()
 	action.sa_flags = 0;
 
 	/* install handlers */
-	if (sigaction(SIGINT, &action, &old_sigint) != 0)
-        {
+	if (sigaction(SIGINT, &action, &old_sigint) != 0) {
 		fprintf(stderr, "Unable to install SIGINT signal handler!\n");
 		exit(EXIT_FAILURE);
-        }
-        if (sigaction(SIGTERM, &action, &old_sigterm) != 0)
-        {
+	}
+	if (sigaction(SIGTERM, &action, &old_sigterm) != 0) {
 		fprintf(stderr, "Unable to install SIGTERM signal handler!\n");
 		exit(EXIT_FAILURE);
-        }
-        memset(&action, 0, sizeof(action));
-        action.sa_handler = &process_hup;
-        action.sa_flags = SIGHUP;
+	}
+	memset(&action, 0, sizeof(action));
+	action.sa_handler = &process_hup;
+	action.sa_flags = SIGHUP;
 
-        if (sigaction(SIGHUP, &action, NULL) != 0)
-        {
+	if (sigaction(SIGHUP, &action, NULL) != 0)
+	{
 		fprintf(stderr, "Warning : Unable to install SIGHUP signal handler!\n");
-        }
+	}
 }
 
 /**
@@ -397,7 +401,7 @@ void daemonize_process(nutcpc_context_t * context, char *runpid)
 		exit(EXIT_FAILURE);
 	}
 
-      /* kill 1st process (keep 2nd) */
+	/* kill 1st process (keep 2nd) */
 	if (p != 0) {
 		exit(0);
 	}
@@ -450,6 +454,7 @@ nuauth_session_t *do_connect(nutcpc_context_t * context, char *username)
 
 	session = nu_client_new_callback(get_username, get_password, 1, err);
 	if (session == NULL) {
+		printf("Problem during session callback init\n");
 		return NULL;
 	}
 
@@ -466,8 +471,8 @@ nuauth_session_t *do_connect(nutcpc_context_t * context, char *username)
 	/* Set hostname from libnuclient if it wasn't specified by the user */
 	if(*context->port == '\0')
 	{
-		if(session->default_port)
-			SECURE_STRNCPY(context->port, session->default_port,
+		if(nu_client_default_port())
+			SECURE_STRNCPY(context->port, nu_client_default_port(),
 			       sizeof(context->port));
 		else
 			SECURE_STRNCPY(context->port, USERPCKT_SERVICE,
@@ -476,8 +481,8 @@ nuauth_session_t *do_connect(nutcpc_context_t * context, char *username)
 
 	if(*context->srv_addr == '\0')
 	{
-		if(session->default_hostname)
-			SECURE_STRNCPY(context->srv_addr, session->default_hostname,
+		if(nu_client_default_hostname())
+			SECURE_STRNCPY(context->srv_addr, nu_client_default_hostname(),
 			       sizeof(context->srv_addr));
 		else
 			SECURE_STRNCPY(context->srv_addr, NUAUTH_IP,
@@ -487,6 +492,7 @@ nuauth_session_t *do_connect(nutcpc_context_t * context, char *username)
 	if (!nu_client_setup_tls(session, context->keyfile, context->certfile,
 	     context->cafile, context->cert_password, err)) {
 		nu_client_delete(session);
+		fprintf(stderr, "Unable to setup TLS params\n");
 		return NULL;
 	}
 
@@ -495,12 +501,14 @@ nuauth_session_t *do_connect(nutcpc_context_t * context, char *username)
 						  context->nuauthdn,
 						  err)) {
 			nu_client_delete(session);
+			fprintf(stderr, "Unable to setup nuauth cert DN\n");
 			return NULL;
 		}
 	}
 
 	if (!nu_client_connect
 	    (session, context->srv_addr, context->port, err)) {
+		fprintf(stderr, "Unable to setup connect\n");
 		nu_client_delete(session);
 		return NULL;
 	}
@@ -515,26 +523,24 @@ void main_loop(nutcpc_context_t * context)
 	int connected = 1;
 	int ret;
 	for (;;) {
-                if (forced_reconnect == 0)
-                {
-		  usleep(context->interval * 1000);
-                }
+		if (forced_reconnect == 0) {
+			usleep(context->interval * 1000);
+		}
 		if (!connected) {
-                        if (forced_reconnect == 0)
-                        {
-			  usleep((unsigned long) context->tempo * 1000000);
-                        }else{
-                          context->tempo = 1;
-                          forced_reconnect = 0;
-                        }
+			if (forced_reconnect == 0) {
+				usleep((unsigned long) context->tempo * 1000000);
+			} else {
+				context->tempo = 1;
+				forced_reconnect = 0;
+			}
 			if (context->tempo < MAX_RETRY_TIME) {
 				context->tempo *= 2;
 			}
 
 			/* try to reconnect to nuauth */
 			if (nu_client_connect
-			    (session, context->srv_addr, context->port,
-			     err) != 0) {
+					(session, context->srv_addr, context->port,
+					 err) != 0) {
 				connected = 1;
 				context->tempo = 1;	/* second */
 			} else {
@@ -543,7 +549,7 @@ void main_loop(nutcpc_context_t * context)
 				nu_client_reset(session);
 			}
 		} else {
-                        forced_reconnect = 0;
+			forced_reconnect = 0;
 			ret = nu_client_check(session, err);
 			if (ret < 0) {
 				/* on error: reset the session */
@@ -569,12 +575,18 @@ char* copy_filename(char* name)
 	char* ret;
 	if (name[0] != '/') {
 		ret = getcwd(cwd, sizeof(cwd));
-		if (!ret) return NULL;
+		if (!ret) {
+			printf("Unable to get current working directory\n");
+			return NULL;
+		}
 		ok = secure_snprintf(buffer, sizeof(buffer), "%s/%s", cwd, name);
-		if (!ok) return NULL;
-		return strdup(buffer);
+		if (!ok) {
+			printf("Unable to copy filename\n");
+			return NULL;
+		}
+		RETURN_NO_LOG strdup(buffer);
 	} else {
-		return strdup(name);
+		RETURN_NO_LOG strdup(name);
 	}
 }
 
@@ -671,6 +683,18 @@ void parse_cmdline_options(int argc, char **argv,
 	}
 }
 
+/**
+ * Stupid wrapper
+ */
+char *wrap_error_message(char *str)
+{
+	if (strncmp(str,"A TLS packet with unexpected length was received.",49) == 0) {
+		RETURN_NO_LOG("Access denied");
+	}
+	return(str);
+}
+
+
 /**
  * Initialize nuclient library
  */
@@ -704,7 +728,7 @@ void init_library(nutcpc_context_t * context, char *username)
 	/* Library failure? */
 	if (session == NULL) {
 		printf("Unable to initiate connection to NuFW gateway\n");
-		printf("Problem: %s\n", nu_client_strerror(err));
+		printf("Problem: %s\n", wrap_error_message(nu_client_strerror(err)));
 		printf("Authentication failed (check parameters)\n");
 		exit(EXIT_FAILURE);
 	}
@@ -752,7 +776,6 @@ int main(int argc, char **argv)
 							printf
 							    ("No running process, starting anyway (deleting lockfile)\n");
 							unlink(runpid);
-							free(runpid);
 						} else {
 							printf
 							    ("Kill existing process with \"-k\" or ignore it with \"-l\" option\n");
