@@ -4,7 +4,7 @@
  **            Victor Stinner <haypo@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: packet_parser.c 4204 2008-01-02 15:35:01Z regit $
+ ** $Id: packet_parser.c 4401 2008-01-30 15:59:24Z lds $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -29,11 +29,6 @@
 
 #include "packet_parser.h"
 
-#ifdef HAVE_CONFIG_H
-#include <config.h>
-#endif
-
-#include <ipv6.h>
 #include <netinet/tcp.h>
 #include <netinet/ip.h>
 #include <netinet/ip6.h>
@@ -111,7 +106,7 @@ unsigned int get_ip_headers(tracking_t * tracking,
 		else
 			memset(tracking->payload, 0,
 			       sizeof(tracking->payload));
-#endif //#ifdef TRACKING_WITH_PAYLOAD
+#endif /* #ifdef TRACKING_WITH_PAYLOAD */
 	} else if (ip->ip_v == 6) {
 #endif
 
