@@ -3,7 +3,7 @@
  ** Written by Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: packet_parser.h 3991 2007-11-30 16:02:50Z lds $
+ ** $Id: packet_parser.h 4328 2008-01-18 23:21:26Z haypo $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -30,7 +30,7 @@
 #define PACKET_PARSER_H
 
 #include "nufw_source.h"
-#include <netinet/in.h>
+#include "ipv6.h"
 #include <sys/types.h>
 
 #ifdef TRACKING_WITH_PAYLOAD
