@@ -3,7 +3,7 @@
  ** Written by Eric Leblond <regit@inL.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: proto.h 3467 2007-06-21 19:13:35Z regit $
+ ** $Id: proto.h 3793 2007-10-08 16:48:27Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -43,12 +43,12 @@
 
 enum proto_type_t {
 	NUFW_PROTO = 0,
-	CLIENT_PROTO,
+	CLIENT_PROTO
 };
 
 enum proto_client_version_t {
 	PROTO_VERSION_V20 = 3,
-	PROTO_VERSION_V22,
+	PROTO_VERSION_V22
 };
 
 #define PROTO_VERSION PROTO_VERSION_V22
@@ -56,7 +56,7 @@ enum proto_client_version_t {
 enum proto_nufw_version_t {
 	PROTO_VERSION_NUFW_V20 = 3,
 	PROTO_VERSION_NUFW_V22,
-	PROTO_VERSION_NUFW_V22_2,
+	PROTO_VERSION_NUFW_V22_2
 };
 
 #define PROTO_NUFW_VERSION PROTO_VERSION_NUFW_V22_2
