@@ -2,7 +2,7 @@
  ** Copyright(C) 2005 Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: acls.h 2738 2007-02-17 13:59:56Z regit $
+ ** $Id: acls.h 4603 2008-04-03 09:53:26Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -29,7 +29,7 @@ gboolean compare_acls(gconstpointer tracking_hdrs1,
 		      gconstpointer tracking_hdrs2);
 
 gpointer acl_create_and_alloc_key(connection_t * kdatas);
-inline guint hash_acl(gconstpointer headers);
+guint hash_acl(gconstpointer headers);
 void free_acl_list(void *datas);
 void get_acls_from_cache(connection_t * conn_elt);
 gpointer acl_duplicate_key(gpointer datas);
