@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2005-2007 INL
+ ** Copyright(C) 2005-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **            Vincent Deffontaines <gryzor@inl.fr>
  **
- ** $Id: audit.c 2738 2007-02-17 13:59:56Z regit $
+ ** $Id: audit.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -29,25 +29,25 @@
  */
 void nuauth_process_poll(int signum)
 {
-	g_message("AUDIT : users   threads : %u/%u max/unassigned",
+	g_message("AUDIT : user    threads : %u/%u max/unassigned",
 		  g_thread_pool_get_max_threads(myaudit->users),
 		  g_thread_pool_unprocessed(myaudit->users));
-	g_message("AUDIT : acls    threads : %u/%u max/unassigned",
+	g_message("AUDIT : acl     threads : %u/%u max/unassigned",
 		  g_thread_pool_get_max_threads(myaudit->acls),
 		  g_thread_pool_unprocessed(myaudit->acls));
 	if (nuauthconf->acl_cache) {
-		g_message("AUDIT :  acls cache : - contains %d elements",
+		g_message("AUDIT :  acl  cache : - contains %d elements",
 			  (g_hash_table_size(myaudit->aclcache)));
 		g_message("AUDIT :               - %u/%u hits/requests",
 			  myaudit->cache_hit_nb, myaudit->cache_req_nb);
 	}
-	g_message("AUDIT : loggers threads : %u/%u max/unassigned",
+	g_message("AUDIT : logger  threads : %u/%u max/unassigned",
 		  g_thread_pool_get_max_threads(myaudit->loggers),
 		  g_thread_pool_unprocessed(myaudit->loggers));
 	g_message("AUDIT : %d connections waiting to be sent packets for.",
 		  (g_hash_table_size(myaudit->conn_list)));
 /*  g_message("AUDIT : overall number of unused threads : %u",
-            g_thread_pool_get_num_unused_threads());*/
+		g_thread_pool_get_num_unused_threads());*/
 #ifdef DEBUG_MEMORY
 	g_mem_profile();
 #endif
