@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2004-2007 INL
+ ** Copyright(C) 2004-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **
- ** $Id: authsrv.c 4128 2007-12-18 13:23:22Z haypo $
+ ** $Id: authsrv.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  */
 
 /*! \file nuauth/authsrv.c
-  \brief Main file
+	\brief Main file
 
   It takes care of init stuffs and runs sheduled tasks at a given interval.
   */
@@ -98,27 +98,27 @@ void start_all_thread_pools()
 		nuauthdatas->ip_authentication_workers = NULL;
 	}
 	/* create acl checker workers */
-	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d acl checkers",
+	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d acl checker threads",
 		    nuauthconf->nbacl_check);
 	nuauthdatas->acl_checkers =
 	    g_thread_pool_new((GFunc) acl_check_and_decide, NULL,
 			      nuauthconf->nbacl_check, POOL_TYPE, NULL);
 
 	/* create user checker workers */
-	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d user checkers",
+	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d user checker threads",
 		    nuauthconf->nbuser_check);
 	nuauthdatas->user_checkers =
 	    g_thread_pool_new((GFunc) user_check_and_decide, NULL,
 			      nuauthconf->nbuser_check, POOL_TYPE, NULL);
 
 	/* create user logger workers */
-	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d user loggers",
+	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN, "Creating %d user logger threads",
 		    nuauthconf->nbloggers);
 	nuauthdatas->user_loggers =
 	    g_thread_pool_new((GFunc) real_log_user_packet, NULL,
 			      nuauthconf->nbloggers, POOL_TYPE, NULL);
 	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-		    "Creating %d user session loggers",
+		    "Creating %d user session logger threads",
 		    nuauthconf->nbloggers);
 	nuauthdatas->user_session_loggers =
 	    g_thread_pool_new((GFunc) log_user_session_thread, NULL,
@@ -127,7 +127,7 @@ void start_all_thread_pools()
 	/* create decisions workers (if needed) */
 	if (nuauthconf->log_users_sync) {
 		log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-			    "Creating %d decision workers",
+			    "Creating %d decision worker threads",
 			    nuauthconf->nbloggers);
 		nuauthdatas->decisions_workers =
 		    g_thread_pool_new((GFunc) decisions_queue_work, NULL,
@@ -142,7 +142,7 @@ void start_all_thread_pools()
 void stop_thread_pool(const char *name, GThreadPool **pool)
 {
 	log_message(DEBUG, DEBUG_AREA_MAIN,
-			"Stop thread pool '%s'", name);
+			"Stopping thread pool '%s'", name);
 	g_thread_pool_free(*pool, TRUE, TRUE);
 	*pool = NULL;
 }
@@ -181,7 +181,7 @@ void stop_all_thread_pools(gboolean soft)
  */
 void stop_threads(gboolean wait)
 {
-	log_message(INFO, DEBUG_AREA_MAIN, "Ask threads to stop.");
+	log_message(INFO, DEBUG_AREA_MAIN, "Asking threads to stop.");
 
 	/* stop command server */
 	if (nuauthconf->use_command_server) {
@@ -195,13 +195,13 @@ void stop_threads(gboolean wait)
 
 	/* wait thread end */
 	if (wait) {
-		log_message(INFO, DEBUG_AREA_MAIN, "Wait thread end ...");
+		log_message(INFO, DEBUG_AREA_MAIN, "Waiting for threads end ...");
 	}
 
 	/* kill push worker */
 	thread_stop(&nuauthdatas->tls_pusher);
 	if (wait) {
-		log_message(DEBUG, DEBUG_AREA_MAIN, "Wait thread 'tls pusher'");
+		log_message(DEBUG, DEBUG_AREA_MAIN, "Waiting for thread 'tls pusher'");
 		g_thread_join(nuauthdatas->tls_pusher.thread);
 	}
 
@@ -216,10 +216,10 @@ void stop_threads(gboolean wait)
 	}
 
 	/* Close nufw and client connections */
-	log_message(INFO, DEBUG_AREA_MAIN, "Close nufw connections");
+	log_message(INFO, DEBUG_AREA_MAIN, "Closing nufw connections");
 	close_nufw_servers();
 
-	log_message(INFO, DEBUG_AREA_MAIN, "Close client connections");
+	log_message(INFO, DEBUG_AREA_MAIN, "Closing client connections");
 	close_clients();
 
 	thread_stop(&nuauthdatas->limited_connections_handler);
@@ -294,10 +294,10 @@ void nuauth_deinit(gboolean soft)
 
 	stop_threads(soft);
 
-	log_message(INFO, DEBUG_AREA_MAIN, "Unload modules");
+	log_message(INFO, DEBUG_AREA_MAIN, "Unloading modules");
 	unload_modules();
 
-	log_message(INFO, DEBUG_AREA_MAIN, "End TLS and audit");
+	log_message(INFO, DEBUG_AREA_MAIN, "Ending TLS and audit");
 	end_tls();
 	end_audit();
 
@@ -340,7 +340,7 @@ void nuauth_atexit()
 {
 	if (g_atomic_int_compare_and_exchange(&nuauth_running, 1, 0)) {
 		log_message(FATAL, DEBUG_AREA_MAIN,
-			    "[+] Stop NuAuth server (exit)");
+			    "[+] Stopping NuAuth server (exit)");
 		nuauth_deinit(FALSE);
 	}
 }
@@ -360,15 +360,15 @@ void nuauth_cleanup(int recv_signal)
 
 	if (recv_signal == SIGINT)
 		log_message(CRITICAL, DEBUG_AREA_MAIN,
-			    "[+] Stop NuAuth server (SIGINT)");
+			    "[+] Stopping NuAuth server (SIGINT)");
 	else if (recv_signal == SIGTERM)
 		log_message(CRITICAL, DEBUG_AREA_MAIN,
-			    "[+] Stop NuAuth server (SIGTERM)");
-	g_message("[+] Stop NuAuth server");
+			    "[+] Stopping NuAuth server (SIGTERM)");
+	g_message("[+] Stopping NuAuth server");
 
 	nuauth_deinit(TRUE);
 
-	g_message("[+] NuAuth exit");
+	g_message("[+] NuAuth exiting");
 	exit(EXIT_SUCCESS);
 }
 
@@ -443,9 +443,9 @@ void print_usage()
 		"nuauth [-hDVv[v[v[v[v[v[v[v[v]]]]]]]]] [-l user_packet_port] [-C local_addr] [-L local_addr] \n"
 		"\t\t[-t packet_timeout]\n"
 		"\t-h : display this help and exit\n"
-		"\t-D : run as a daemon, send debug messages to syslog (else stdout/stderr)\n"
+		"\t-D : run as a daemon, send messages to syslog (else stdout/stderr)\n"
 		"\t-V : display version and exit\n"
-		"\t-v : increase debug level (+1 for each 'v') (max useful number : 10)\n"
+		"\t-v : increase verbosity level (+1 for each 'v') (max useful number : 10)\n"
 		"\t-p : specify listening TCP port (this port waits for nufw) (default : 4128)\n"
 		"\t-l : specify listening TCP port (this port waits for clients) (default : 4129)\n"
 		"\t-L : specify NUFW listening IP address (local) (this address waits for nufw data) (default : 127.0.0.1)\n"
@@ -495,7 +495,7 @@ void parse_options(int argc, char **argv, command_line_params_t * params)
 			/* Address we listen on for NUFW originating packets */
 			g_free(params->nuauth_nufw_listen_addr);
 			params->nuauth_nufw_listen_addr = g_strdup(optarg);
-			printf("Waiting for Nufw daemon packets on %s\n",
+			printf("Waiting for nufw daemon packets on %s\n",
 			       params->nuauth_nufw_listen_addr);
 			break;
 
@@ -658,7 +658,7 @@ void configure_app(int argc, char **argv)
 		exit(EXIT_FAILURE);
 	}
 
-	log_message(INFO, DEBUG_AREA_MAIN, "Start NuAuth server.");
+	log_message(INFO, DEBUG_AREA_MAIN, "Starting NuFW authentication server.");
 
 	/* init gcrypt and gnutls */
 #ifdef GCRYPT_PTHEAD_IMPLEMENTATION
@@ -702,7 +702,7 @@ void configure_app(int argc, char **argv)
 		daemonize();
 	} else {
 		g_message("[+] Starting nuauth " VERSION
-			  " ($Revision: 4128 $) with config "
+			  " ($Revision: 4601 $) with config "
 			  DEFAULT_CONF_FILE );
 	}
 }
@@ -892,7 +892,7 @@ void nuauth_main_loop()
 	double sec;
 	unsigned long ms;
 
-	g_message("[+] NuAuth started.");
+	g_message("[+] NuFW authentication daemon started.");
 
 	/* create timer and add main cleanup function to cleanup list */
 	timer = g_timer_new();
