@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2005-2007 INL
+ ** Copyright(C) 2005-2008 INL
  ** Written by  Eric Leblond <regit@inl.fr>
  **
- ** $Id: client_mngr.c 3889 2007-10-31 13:56:45Z regit $
+ ** $Id: client_mngr.c 4603 2008-04-03 09:53:26Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -178,12 +178,12 @@ nu_error_t delete_client_by_socket_ext(int socket, int use_lock)
 	return NU_EXIT_OK;
 }
 
-inline nu_error_t delete_client_by_socket(int socket)
+nu_error_t delete_client_by_socket(int socket)
 {
 	return delete_client_by_socket_ext(socket, 1);
 }
 
-inline user_session_t *get_client_datas_by_socket(int socket)
+user_session_t *get_client_datas_by_socket(int socket)
 {
 	void *ret;
 
@@ -194,7 +194,7 @@ inline user_session_t *get_client_datas_by_socket(int socket)
 	return ret;
 }
 
-inline GSList *get_client_sockets_by_ip(struct in6_addr * ip)
+GSList *get_client_sockets_by_ip(struct in6_addr * ip)
 {
 	void *ret;
 
@@ -204,7 +204,7 @@ inline GSList *get_client_sockets_by_ip(struct in6_addr * ip)
 	return ret;
 }
 
-inline guint get_number_of_clients()
+guint get_number_of_clients()
 {
 	return g_hash_table_size(client_conn_hash);
 }
@@ -220,7 +220,7 @@ static gboolean look_for_username_callback(gpointer key,
 	}
 }
 
-inline user_session_t *look_for_username(const gchar * username)
+user_session_t *look_for_username(const gchar * username)
 {
 	void *ret;
 	g_mutex_lock(client_mutex);
@@ -303,17 +303,17 @@ char warn_clients(struct msg_addr_set *global_msg)
 					ntohs(global_msg->msg->length));
 			if (ret < 0) {
 				log_message(WARNING, DEBUG_AREA_USER,
-						"Fails to send warning to client(s).");
-				badsockets = g_slist_prepend(badsockets, ipsockets->data);
+						"Failed to send warning to client(s).");
+				badsockets = g_slist_prepend(badsockets, GINT_TO_POINTER(ipsockets->data));
 			}
 		}
 		if (badsockets) {
 			for (; badsockets; badsockets = badsockets->next) {
-				int sockno = (int)badsockets->data;
+				int sockno = GPOINTER_TO_INT(badsockets->data);
 				nu_error_t ret = delete_client_by_socket_ext(sockno, 0);
 				if (ret != NU_EXIT_OK) {
 					log_message(WARNING, DEBUG_AREA_USER,
-						"Fails to destroy socket in hash.");
+						"Failed to destroy socket in hash.");
 				}
 			}
 			g_slist_free(badsockets);
