@@ -2,7 +2,7 @@
  ** Copyright(C) 2005-2007 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **
- ** $Id: client_mngr.h 3871 2007-10-30 07:56:51Z regit $
+ ** $Id: client_mngr.h 4603 2008-04-03 09:53:26Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -32,9 +32,9 @@ void add_client(int socket, gpointer datas);
 
 nu_error_t delete_client_by_socket(int c);
 
-inline user_session_t *get_client_datas_by_socket(int c);
+user_session_t *get_client_datas_by_socket(int c);
 
-inline GSList *get_client_sockets_by_ip(struct in6_addr *ip);
+GSList *get_client_sockets_by_ip(struct in6_addr *ip);
 
 user_session_t *look_for_username(const gchar * username);
 
@@ -62,9 +62,9 @@ nu_error_t activate_client_by_socket(int socket);
 guint get_number_of_clients();
 
 struct username_counter {
-  const char* name;
-  int max;
-  int counter;
+	const char* name;
+	int max;
+	int counter;
 };
 
 
