@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2007 INL
+ ** Copyright(C) 2007-2008 INL
  ** Written by Victor Stinner <victor.stinner@inl.fr>
  **	       Eric Leblond <eric@inl.fr>
  **
- ** $Id: command.c 4120 2007-12-18 12:25:04Z haypo $
+ ** $Id: command.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -34,7 +34,7 @@ const char* COMMAND_HELP =
 "firewalls: list connected nufw firewalls\n"
 "packets count: display number of decision waiting packets\n"
 "refresh cache: refresh all caches\n"
-"disconnect ID: disconnect an user with his session identifier\n"
+"disconnect ID: disconnect a user with his session identifier\n"
 "disconnect all: disconnect all users\n"
 "uptime: display nuauth starting time and uptime\n"
 "reload: reload nuauth configuration\n"
@@ -80,7 +80,7 @@ int command_new(command_t * this)
 	/* create socket */
 	this->socket = socket(AF_UNIX, SOCK_STREAM, 0);
 	if (this->socket == -1) {
-		g_warning("[%i] Command server: enable to create UNIX socket %s: %s",
+		g_warning("[%i] Command server: unable to create UNIX socket %s: %s",
 			    getpid(), addr.sun_path, g_strerror(errno));
 		return 0;
 	}
@@ -114,7 +114,7 @@ int command_new(command_t * this)
 void command_client_close(command_t * this)
 {
 	log_message(WARNING, DEBUG_AREA_MAIN,
-		    "Command server: close client connection");
+		    "Command server: closing client connection");
 	close(this->client);
 	this->client = -1;
 	this->select_max = this->socket + 1;
@@ -144,7 +144,7 @@ int command_client_accept(command_t * this)
 	ret = recv(this->client, buffer, sizeof(buffer)-1, 0);
 	if (ret < 0) {
 		log_message(CRITICAL, DEBUG_AREA_MAIN,
-			    "Command server: client doesn't send version");
+			    "Command server: client didn't send version");
 		command_client_close(this);
 		return 0;
 	}
@@ -253,7 +253,7 @@ int command_do_disconnect(int sock)
 }
 
 /**
- * Disconnect all client
+ * Disconnect all clients
  **/
 int command_disconnect_all(command_t *this, encoder_t *encoder)
 {
@@ -420,7 +420,7 @@ void command_client_run(command_t * this)
 	{
 		log_message(WARNING, DEBUG_AREA_MAIN,
 			    "Command server: client command is too long, "
-			    "disconnect him.");
+			    "disconnecting him.");
 		command_client_close(this);
 	}
 	buffer[ret] = 0;
