@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@gryzor.com>
  **     INL : http://www.inl.fr/
  **
- ** $Id: connections.c 4256 2008-01-07 12:42:42Z regit $
+ ** $Id: connections.c 4607 2008-04-03 12:58:08Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -27,6 +27,8 @@
  * @{
  */
 
+/** global lock for the conn list. */
+GStaticMutex insert_mutex;
 
 void free_connection_callback(gpointer conn, gpointer unused)
 {
@@ -139,10 +141,10 @@ void free_connection(connection_t * conn)
 }
 
 #define COPY_IFACE_NAME(copy, orig, iface) \
-    do { if (orig->iface) \
-            { copy->iface = g_strndup(orig->iface,IFNAMSIZ); }  \
-        else { copy->iface = NULL; } \
-    } while (0)
+	do { if (orig->iface) \
+		{ copy->iface = g_strndup(orig->iface,IFNAMSIZ); }  \
+		else { copy->iface = NULL; } \
+	} while (0)
 
 /** Duplicate an iface_nfo
  *
@@ -202,7 +204,6 @@ connection_t *duplicate_connection(connection_t * element)
 			    &(element->iface_nfo));
 
 	/* Nullify needed internal field */
-	conn_copy->tls = NULL;
 	conn_copy->acl_groups = NULL;
 	conn_copy->user_groups = NULL;
 	conn_copy->packet_id = NULL;
@@ -411,7 +412,7 @@ nu_error_t print_tracking_t(tracking_t *tracking)
 	if (! tracking_display)
 		return NU_EXIT_ERROR;
 	
-	g_message(tracking_display);
+	g_message("%s", tracking_display);
 
 	g_free(tracking_display);
 	return NU_EXIT_OK;
@@ -496,7 +497,7 @@ gint print_connection(gpointer data, gpointer userdata)
 	g_free(str_os);	
 	g_free(str_app);	
 
-	g_message(message);
+	g_message("%s", message);
 
 	g_free(message);
 	return 1;
