@@ -1,7 +1,7 @@
 /*
 ** Copyright(C) 2005,2006,2007 Eric Leblond <regit@inl.fr>
 **
-** $Id: connections.h 3799 2007-10-09 13:08:22Z regit $
+** $Id: connections.h 4472 2008-02-15 12:53:55Z lds $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -38,10 +38,10 @@ typedef enum {
 	AUTH_STATE_USERPCKT,	/*!< Connection received from an user: see user_request() */
 	AUTH_STATE_READY,	/*!< (see search_and_fill_completing()) */
 
-    /**
-     * State used when a connection is send to acl_checkers queue: read ACLs
-     * from cache or external source. See acl_check_and_decide().
-     */
+	/**
+	 * State used when a connection is send to acl_checkers queue: read ACLs
+	 * from cache or external source. See acl_check_and_decide().
+	 */
 	AUTH_STATE_COMPLETING,
 	AUTH_STATE_DONE,	/*!< This state is set when the connection will be only used for logging purpose */
 	AUTH_STATE_HELLOMODE,	/*!< This connection is treated by the HELLO authentication mode */
@@ -52,7 +52,10 @@ typedef enum {
 	ACL_FLAGS_NONE = 0,
 	/* This ACL wants asynchronous logging */
 	ACL_FLAGS_ASYNC_BIT = 0,
-	ACL_FLAGS_ASYNC = (1 << ACL_FLAGS_ASYNC_BIT)
+	ACL_FLAGS_ASYNC = (1 << ACL_FLAGS_ASYNC_BIT),
+	/* This ACL don't want to log */
+	ACL_FLAGS_NOLOG_BIT = 1,
+	ACL_FLAGS_NOLOG = (1 << ACL_FLAGS_NOLOG_BIT),
 } acl_flags_t;
 
 
@@ -102,11 +105,11 @@ typedef struct {
 	uint32_t mark;		/*!< Number used for marking set to user numeric identity at start */
 	char *username;		/*!< User name */
 
- /**
-  * ACL related groups.
-  *
-  * Contains the list of acl corresponding to the IPv4 header
-  */
+	/**
+	 * ACL related groups.
+	 *
+	 * Contains the list of acl corresponding to the IPv4 header
+	 */
 	GSList *acl_groups;	/*!< ACL group list (of type ::acl_group) */
 	GSList *user_groups;	/*!< User groups */
 	struct user_cached_datas *cacheduserdatas;	/* Pointer to cache */
@@ -137,7 +140,7 @@ guint hash_connection(gconstpointer conn_p);
 /** hash table containing the connections. */
 GHashTable *conn_list;
 /** global lock for the conn list. */
-GStaticMutex insert_mutex;
+extern GStaticMutex insert_mutex;
 
 
 gboolean get_old_conn(gpointer key, gpointer value, gpointer user_data);
