@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2005-2007 INL
+ ** Copyright(C) 2005-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **
- ** $Id: conntrack.c 4128 2007-12-18 13:23:22Z haypo $
+ ** $Id: conntrack.c 4611 2008-04-04 08:32:37Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -295,15 +295,16 @@ void *limited_connection_handler(GMutex * mutex)
 #ifdef DEBUG_ENABLE
 			else {
 				log_message(VERBOSE_DEBUG, DEBUG_AREA_PACKET,
-					    "connection not found can not be destroyed");
+					    "connection not found: can not be destroyed");
 			}
 #endif
 			g_free(message->datas);
 			break;
 
 		case UPDATE_MESSAGE:
-		/** here we get message from nufw kernel connection is ASSURED
-                 * we have to limit it if needed and log the state change if needed */
+			/* here we get message from nufw kernel connection is ASSURED
+			 * we have to limit it if needed and log the state change if needed
+			 */
 			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_GW,
 					  "received update message for a conntrack entry");
 			elt =
