@@ -2,7 +2,7 @@
 ** Copyrigh 2002-2004 Vincent Deffontaines <vincent@gryzor.com>
 ** INL http://www.inl.fr/
 **
-** $Id: debug.c 2738 2007-02-17 13:59:56Z regit $
+** $Id: debug.c 3793 2007-10-08 16:48:27Z regit $
 **
 **
 ** This program is free software; you can redistribute it and/or modify
@@ -29,7 +29,7 @@ void process_g_syslog(const gchar * log_domain, GLogLevelFlags log_level,
 		      const gchar * message, gpointer user_data)
 {
 	int syslog_level;
-	syslog_level = rint(log(log_level) / log(2));
+	syslog_level = rint(log((double)log_level) / log(2.0));
 	syslog(LOG_FACILITY || syslog_level, message);
 }
 
