@@ -1,10 +1,9 @@
-
 /*
- ** Copyright(C) 2003-2006 INL
+ ** Copyright(C) 2003-2008 INL
  **     written by Eric Leblond <eric@regit.org>
  **                Vincent Deffontaines <vincent@gryzor.com>
  **
- ** $Id: ldap.c 4165 2007-12-21 10:33:01Z regit $
+ ** $Id: ldap.c 4590 2008-03-27 17:17:46Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -53,6 +52,8 @@ typedef unsigned long digit_t;
 #endif
 typedef digit_t number_t[DIGIT_COUNT];
 
+#define LDAP_MAX_TRY 2
+
 /**
  * Returns version of nuauth API
  */
@@ -136,7 +137,7 @@ char *number_to_decimal(number_t number)
 int decimal_to_number(const char *orig_decimal, number_t number)
 {
 	ssize_t decimal_len = strlen(orig_decimal);
-	char *decimal = strdup(orig_decimal);
+	char *decimal = g_strdup(orig_decimal);
 	char *err;
 	unsigned char index;
 	for (index = 0; index < DIGIT_COUNT; index++)
@@ -148,13 +149,13 @@ int decimal_to_number(const char *orig_decimal, number_t number)
 		number[index] = strtol(decimal + decimal_len, &err, 10);
 		index++;
 		if (err == NULL || *err != 0 || DIGIT_COUNT <= index) {
-			free(decimal);
+			g_free(decimal);
 			return 0;
 		}
 	}
 	decimal[decimal_len] = 0;
 	number[index] = strtol(decimal, &err, 10);
-	free(decimal);
+	g_free(decimal);
 	if (err == NULL || *err != 0)
 		return 0;
 	else
@@ -204,7 +205,7 @@ G_MODULE_EXPORT gboolean init_module_from_conf(module_t * module)
 
 
 	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-		    "Ldap module ($Revision: 4165 $)");
+		    "Ldap module ($Revision: 4590 $)");
 	if (!module->configfile) {
 		configfile = DEFAULT_CONF_FILE;
 	} else {
@@ -386,13 +387,13 @@ static char *ipv6_to_base10(struct in6_addr *addr)
  *
  * \verbatim
 Abstract from RFC 2254
-   Character       ASCII value
-   ---------------------------
-    *               0x2a
-    (               0x28
-    )               0x29
-    \               0x5c
-    NUL             0x00
+	Character       ASCII value
+	---------------------------
+	 *               0x2a
+	 (               0x28
+	 )               0x29
+	 \               0x5c
+	 NUL             0x00
 For example * is coded \2a
 \endverbatim
  *
@@ -485,24 +486,13 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element,
 	struct acl_group *this_acl;
 	struct weighted_acl *this = NULL;
 	LDAPMessage *res, *result;
-	int err;
+	int err, try;
 	struct ldap_params *params = (struct ldap_params *) params_p;
 	LDAP *ld = g_private_get(params->ldap_priv);
 	gchar *ip_src;
 	gchar *ip_dst;
 	gchar *prov_string;
 
-	if (ld == NULL) {
-		/* init ldap has never been done */
-		ld = ldap_conn_init(params);
-		if (ld == NULL) {
-			log_message(SERIOUS_WARNING, DEBUG_AREA_AUTH,
-				    "Can not initiate LDAP conn\n");
-			return NULL;
-		}
-		g_private_set(params->ldap_priv, ld);
-	}
-
 	if (params->ldap_use_ipv4_schema) {
 		if (!is_ipv4(&element->tracking.saddr) ||
 				!is_ipv4(&element->tracking.daddr)) {
@@ -521,8 +511,8 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element,
 		ip_dst = ipv6_to_base10(&element->tracking.daddr);
 	}
 	if (ip_src == NULL || ip_dst == NULL) {
-		free(ip_src);
-		free(ip_dst);
+		g_free(ip_src);
+		g_free(ip_dst);
 		return NULL;
 	}
 
@@ -547,8 +537,8 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element,
 				log_message(WARNING, DEBUG_AREA_MAIN,
 					    "LDAP query too big (more than %d bytes)\n",
 					    LDAP_QUERY_SIZE);
-				free(ip_src);
-				free(ip_dst);
+				g_free(ip_src);
+				g_free(ip_dst);
 				return NULL;
 			}
 			break;
@@ -572,13 +562,13 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element,
 				log_message(WARNING, DEBUG_AREA_MAIN,
 					    "LDAP query too big (more than %d bytes)\n",
 					    LDAP_QUERY_SIZE);
-				free(ip_src);
-				free(ip_dst);
+				g_free(ip_src);
+				g_free(ip_dst);
 				return NULL;
 			}
 		}
-		free(ip_src);
-		free(ip_dst);
+		g_free(ip_src);
+		g_free(ip_dst);
 
 		/* finish filter */
 		if (element->os_sysname) {
@@ -662,48 +652,68 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element,
 			log_message(WARNING, DEBUG_AREA_MAIN,
 				    "LDAP query too big (more than %d bytes)\n",
 				    LDAP_QUERY_SIZE);
-			free(ip_src);
-			free(ip_dst);
+			g_free(ip_src);
+			g_free(ip_dst);
 			return NULL;
 		}
-		free(ip_src);
-		free(ip_dst);
+		g_free(ip_src);
+		g_free(ip_dst);
 	}
 
-	/* send query and wait result */
-	timeout.tv_sec = params->ldap_request_timeout;
-	timeout.tv_usec = 0;
-#ifdef PERF_DISPLAY_ENABLE
-	{
-		struct timeval tvstart, tvend, result;
-		if (nuauthconf->debug_areas & DEBUG_AREA_PERF) {
-			gettimeofday(&tvstart, NULL);
-		}
-#endif
-
-		err =
-		    ldap_search_st(ld, params->ldap_acls_base_dn,
-				   LDAP_SCOPE_SUBTREE, filter, NULL, 0,
-				   &timeout, &res);
-
-#ifdef PERF_DISPLAY_ENABLE
-		if (nuauthconf->debug_areas & DEBUG_AREA_PERF) {
-			gettimeofday(&tvend, NULL);
-			timeval_substract(&result, &tvend, &tvstart);
-			log_message(INFO, DEBUG_AREA_PERF, "Ldap query time: %.1f msec",
-					(double)result.tv_sec*1000+(double)(result.tv_usec/1000));
-		}
-	}
-#endif
-	if (err != LDAP_SUCCESS) {
-		if (err == LDAP_SERVER_DOWN) {
-			/* we lost connection, so disable current one */
-			log_message(WARNING, DEBUG_AREA_MAIN,
-				    "disabling current connection");
-			ldap_unbind(ld);
-			ld = NULL;
+	try = 0;
+	do {
+		try++;
+		if (ld == NULL) {
+			/* init ldap has never been done */
+			ld = ldap_conn_init(params);
+			if (ld == NULL) {
+				log_message(SERIOUS_WARNING, DEBUG_AREA_AUTH,
+						"Can not initiate LDAP conn\n");
+				break;
+			}
 			g_private_set(params->ldap_priv, ld);
 		}
+
+		/* send query and wait result */
+		timeout.tv_sec = params->ldap_request_timeout;
+		timeout.tv_usec = 0;
+#ifdef PERF_DISPLAY_ENABLE
+		{
+			struct timeval tvstart, tvend, result;
+			if (nuauthconf->debug_areas & DEBUG_AREA_PERF) {
+				gettimeofday(&tvstart, NULL);
+			}
+#endif
+
+			err =
+				ldap_search_st(ld, params->ldap_acls_base_dn,
+						LDAP_SCOPE_SUBTREE, filter, NULL, 0,
+						&timeout, &res);
+
+#ifdef PERF_DISPLAY_ENABLE
+			if (nuauthconf->debug_areas & DEBUG_AREA_PERF) {
+				gettimeofday(&tvend, NULL);
+				timeval_substract(&result, &tvend, &tvstart);
+				log_message(INFO, DEBUG_AREA_PERF, "Ldap query time: %.1f msec",
+						(double)result.tv_sec*1000+(double)(result.tv_usec/1000));
+			}
+		}
+#endif
+		if (err != LDAP_SUCCESS) {
+			if (err == LDAP_SERVER_DOWN) {
+				/* we lost connection, so disable current one */
+				log_message(WARNING, DEBUG_AREA_MAIN,
+						"disabling current connection");
+				ldap_unbind(ld);
+				ld = NULL;
+				g_private_set(params->ldap_priv, ld);
+			} else {
+				break;
+			}
+		}
+	} while ((err != LDAP_SUCCESS) || (try < LDAP_MAX_TRY));
+
+	if ((try == LDAP_MAX_TRY) && (err != LDAP_SUCCESS)) {
 		log_message(WARNING, DEBUG_AREA_MAIN,
 			    "invalid return from ldap_search_st : %s\n",
 			    ldap_err2string(err));
