@@ -1,8 +1,9 @@
 /*
- ** Copyright(C) 2006 INL
+ ** Copyright(C) 2006,2007,2008 INL
+ **	written by Pierre Chifflier <chifflier AT inl DOT fr>
  **	written by Victor Stinner <victor.stinner AT haypocalc.com>
  **
- ** $Id: nuprelude.c 3771 2007-09-25 23:22:48Z regit $
+ ** $Id: nuprelude.c 4607 2008-04-03 12:58:08Z pollux $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -33,7 +34,7 @@
 
 #define NUFW_ANALYZER_MANUFACTURER "http://www.nufw.org/"
 #define NUFW_ANALYZER_CLASS "Firewall"
-#define NUFW_ANALYZER_VERSION NUAUTH_FULL_VERSION
+#define NUFW_ANALYZER_VERSION VERSION
 #define NUFW_ANALYZER_MODEL "NuFW"
 
 #define CLIENT_ANALYZER_NAME "libnuclient"
@@ -101,7 +102,7 @@ G_MODULE_EXPORT gboolean init_module_from_conf(module_t * module)
 
 
 	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-		    "Log_nuprelude module ($Revision: 3771 $)");
+		    "Log_nuprelude module ($Revision: 4607 $)");
 
 	params->packet_tpl = g_private_new((GDestroyNotify) destroy_idmef);
 	params->session_tpl = g_private_new((GDestroyNotify) destroy_idmef);
@@ -116,7 +117,7 @@ static void del_idmef_object(idmef_message_t * message, const char *object)
 {
 	idmef_value_t *val;
 	idmef_path_t *path;
-	if (idmef_path_new(&path, object) < 0) {
+	if (idmef_path_new(&path, "%s", object) < 0) {
 		return;
 	}
 	if (0 < idmef_path_get(path, message, &val)) {
@@ -137,7 +138,7 @@ static int add_idmef_object(idmef_message_t * message, const char *object,
 	idmef_path_t *path;
 
 
-	ret = idmef_path_new(&path, object);
+	ret = idmef_path_new(&path, "%s", object);
 	if (ret < 0) {
 		log_message(DEBUG, DEBUG_AREA_MAIN,
 			    "Prelude: Fail to set attribute %s=%s: %s",
@@ -266,8 +267,6 @@ static void feed_source_libnuclient(idmef_message_t *idmef)
 			 "alert.source(0).service.iana_protocol_number",
 			 "6");
 	add_idmef_object(idmef, "alert.source(0).service.protocol", "tcp");
-	add_idmef_object(idmef, "alert.source(0).service.name",
-			 "nufw-client");
 }
 
 /**
@@ -375,65 +374,29 @@ idmef_message_t* create_from_template(idmef_message_t *tpl, connection_t *conn)
 }
 
 /**
- * Set operating system informations of a IDMEF message:
- *  - create an analyzer to store libnuclient informations
- *  - set name, model, class, manufacturer
- *  - set OS type and version
+ * Set operating system information on the client (OS type and version)
  */
-void set_os_infos(idmef_message_t *idmef, char* osname, char *osrelease, char *osversion)
+static void set_os_infos(idmef_message_t *idmef, const char* osname, const char *osrelease, const char *osversion)
 {
-	idmef_alert_t *alert;
-	idmef_analyzer_t *analyzer;
-	prelude_string_t *string = NULL;
-	gchar* fullversion;
-	int ret;
+	char buffer[256];
 
-	alert = idmef_message_get_alert(idmef);
-	if (!alert)
-		return;
+	add_idmef_object(idmef, "alert.additional_data(0).type", "string");
+	add_idmef_object(idmef, "alert.additional_data(0).meaning", "Client OS");
+	secure_snprintf(buffer, sizeof(buffer), "%s %s %s", osname, osrelease, osversion);
+	add_idmef_object(idmef, "alert.additional_data(0).data", buffer);
+}
 
-	ret = idmef_alert_new_analyzer(alert, &analyzer, 2);
-	if (ret < 0)
-		return;
+/**
+ * Set information on NuFW (ip address, port)
+ */
+static void set_nufw_infos(idmef_message_t *idmef, const char *nufw_address, const char *nufw_port)
+{
+	char buffer[256];
 
-
-	/* configure analyzer */
-	ret = idmef_analyzer_new_name(analyzer, &string);
-	if (ret < 0)
-		return;
-	prelude_string_set_constant(string, CLIENT_ANALYZER_NAME);
-
-	ret = idmef_analyzer_new_model(analyzer, &string);
-	if (ret < 0)
-		return;
-	prelude_string_set_constant(string, CLIENT_ANALYZER_MODEL);
-
-	ret = idmef_analyzer_new_class(analyzer, &string);
-	if (ret < 0)
-		return;
-	prelude_string_set_constant(string, CLIENT_ANALYZER_CLASS);
-
-	ret = idmef_analyzer_new_manufacturer(analyzer, &string);
-	if (ret < 0)
-		return;
-	prelude_string_set_constant(string, CLIENT_ANALYZER_MANUFACTURER);
-
-	/* OS informations */
-	ret = idmef_analyzer_new_ostype(analyzer, &string);
-	if (ret < 0)
-		return;
-	prelude_string_set_dup(string, osname);
-
-	fullversion = g_strdup_printf("%s %s", osrelease, osversion);
-	ret = idmef_analyzer_new_osversion(analyzer, &string);
-	if (ret < 0)
-		return;
-	if (fullversion) {
-		prelude_string_set_dup(string, fullversion);
-		g_free(fullversion);
-	} else {
-		prelude_string_set_dup(string, osversion);
-	}
+	add_idmef_object(idmef, "alert.additional_data(1).type", "string");
+	add_idmef_object(idmef, "alert.additional_data(1).meaning", "NuFW server address");
+	secure_snprintf(buffer, sizeof(buffer), "%s:%s", nufw_address, nufw_port);
+	add_idmef_object(idmef, "alert.additional_data(1).data", buffer);
 }
 
 void set_source0_address(idmef_message_t *idmef, struct in6_addr *addr)
@@ -443,6 +406,9 @@ void set_source0_address(idmef_message_t *idmef, struct in6_addr *addr)
 	add_idmef_object(idmef,
 			 "alert.source(0).node.address(0).address",
 			 ip_ascii);
+	add_idmef_object(idmef,
+			 "alert.source(0).spoofed",
+			 "no");
 }
 
 /**
@@ -465,10 +431,11 @@ static idmef_message_t *create_message_packet(idmef_message_t * tpl,
 		return NULL;
 	}
 
-	if (state == TCP_STATE_DROP)
+	if (state == TCP_STATE_DROP) {
 		tmp_buffer = "failed";
-	else
+	} else {
 		tmp_buffer = "succeeded";
+	}
 	add_idmef_object(idmef, "alert.assessment.impact.completion", tmp_buffer);
 	add_idmef_object(idmef, "alert.classification.text", state_text);
 	add_idmef_object(idmef, "alert.assessment.impact.severity", severity);
@@ -481,8 +448,7 @@ static idmef_message_t *create_message_packet(idmef_message_t * tpl,
 	add_idmef_object(idmef, "alert.target(0).node.address(0).address", ip_ascii);
 
 	/* IP protocol */
-	if (secure_snprintf
-	    (buffer, sizeof(buffer), "%hu", conn->tracking.protocol)) {
+	if (secure_snprintf(buffer, sizeof(buffer), "%hu", conn->tracking.protocol)) {
 		add_idmef_object(idmef,
 				 "alert.source(0).service.iana_protocol_number",
 				 buffer);
@@ -526,16 +492,6 @@ static idmef_message_t *create_message_packet(idmef_message_t * tpl,
 		}
 	}
 
-	/* informations about nufw server */
-	if (conn->tls) {
-		add_idmef_object(idmef, "alert.source(1).process.name", "nufw");
-		add_idmef_object(idmef, "alert.source(1).service.protocol", "tcp");
-		add_idmef_object(idmef, "alert.source(1).service.port", nuauthconf->authreq_port);
-		add_idmef_object(idmef, "alert.source(1).service.iana_protocol_number", "6");
-		FORMAT_IPV6(&conn->tls->peername, ip_ascii);
-		add_idmef_object(idmef, "alert.source(1).node.address(0).address", ip_ascii);
-	}
-
 	/* user informations */
 	if (conn->username != NULL) {
 		add_idmef_object(idmef,
@@ -546,7 +502,7 @@ static idmef_message_t *create_message_packet(idmef_message_t * tpl,
 				 "alert.source(0).user.user_id(0).name",
 				 conn->username);
 		if (secure_snprintf
-		    (buffer, sizeof(buffer), "%lu", conn->user_id)) {
+		    (buffer, sizeof(buffer), "%lu", (long)conn->user_id)) {
 			add_idmef_object(idmef,
 					 "alert.source(0).user.user_id(0).number",
 					 buffer);
@@ -572,6 +528,12 @@ static idmef_message_t *create_message_packet(idmef_message_t * tpl,
 		set_os_infos(idmef, conn->os_sysname, conn->os_release, conn->os_version);
 	}
 
+	/* informations about nufw server */
+	if (conn->tls != NULL) {
+		FORMAT_IPV6(&conn->tls->peername, ip_ascii);
+		set_nufw_infos(idmef, ip_ascii, nuauthconf->authreq_port);
+	}
+
 	return idmef;
 }
 
@@ -591,8 +553,10 @@ static void add_user_information(idmef_message_t * idmef,
 		add_idmef_object(idmef,
 				 "alert.source(0).user.user_id(0).name",
 				 session->user_name);
-		if (userid_is_valid && secure_snprintf
-		    (buffer, sizeof(buffer), "%lu", session->user_id)) {
+		if (userid_is_valid &&
+				secure_snprintf (buffer,
+						sizeof(buffer),
+						"%lu", (long)session->user_id)) {
 			add_idmef_object(idmef,
 					 "alert.source(0).user.user_id(0).number",
 					 buffer);
@@ -636,8 +600,7 @@ static idmef_message_t *create_message_session(idmef_message_t * tpl,
 	add_user_information(idmef, session, 1);
 
 	FORMAT_IPV6(&session->server_addr, ip_ascii);
-	add_idmef_object(idmef,
-			"alert.target(0).node.address(0).address", ip_ascii);
+	add_idmef_object(idmef, "alert.target(0).node.address(0).address", ip_ascii);
 
 	/* os informations */
 	set_os_infos(idmef, session->sysname, session->release, session->version);
@@ -659,13 +622,10 @@ static idmef_message_t *create_message_autherr(idmef_message_t * tpl,
 	}
 
 	add_idmef_object(idmef, "alert.assessment.impact.completion", "failed");
-	add_idmef_object(idmef, "alert.assessment.impact.severity",
-			 severity);
+	add_idmef_object(idmef, "alert.assessment.impact.severity", severity);
 
-	add_idmef_object(idmef, "alert.classification.text",
-			 "Authentication error");
-	add_idmef_object(idmef, "alert.assessment.impact.description",
-			 text);
+	add_idmef_object(idmef, "alert.classification.text", "Authentication error");
+	add_idmef_object(idmef, "alert.assessment.impact.description", text);
 
 	/* source address */
 	set_source0_address(idmef, &session->addr);
@@ -674,8 +634,7 @@ static idmef_message_t *create_message_autherr(idmef_message_t * tpl,
 	add_idmef_object(idmef,	"alert.source(0).service.port", buffer);
 
 	FORMAT_IPV6(&session->server_addr, ip_ascii);
-	add_idmef_object(idmef,
-			"alert.target(0).node.address(0).address", ip_ascii);
+	add_idmef_object(idmef, "alert.target(0).node.address(0).address", ip_ascii);
 
 	/* set user informations */
 	add_user_information(idmef, session, 0);
@@ -695,27 +654,26 @@ G_MODULE_EXPORT gint user_packet_logs(connection_t * element,
 	char *state_text;
 	char *severity;
 
-	impact = "notify connection state change";
+	state_text = "Connection state change";
 	switch (state) {
 	case TCP_STATE_OPEN:
-		state_text = "Open connection";
+		impact = "Connection opened";
 		severity = "low";
 		break;
 	case TCP_STATE_ESTABLISHED:
-		state_text = "Connection established";
+		impact = "Connection established";
 		severity = "info";
 		break;
 	case TCP_STATE_CLOSE:
-		state_text = "Close connection";
+		impact = "Connection closed";
 		severity = "low";
 		break;
 	case TCP_STATE_DROP:
 		if (element->username != NULL) {
-			state_text = "Drop auth connection";
+			impact = "Authenticated connection dropped";
 			severity = "high";
 		} else {
-			state_text =
-			    "Drop unauth connection (auth timeout)";
+			impact = "Unauthenticated connection dropped";
 			severity = "medium";
 		}
 		break;
@@ -727,14 +685,14 @@ G_MODULE_EXPORT gint user_packet_logs(connection_t * element,
 	tpl = g_private_get(params->packet_tpl);
 	if (!tpl) {
 		tpl = create_packet_template();
-		if (!tpl)
+		if (!tpl) {
 			return -1;
+		}
 		g_private_set(params->packet_tpl, tpl);
 	}
 
 	/* feed message fields */
-	message =
-	    create_message_packet(tpl, state, element, state_text, impact,
+	message = create_message_packet(tpl, state, element, state_text, impact,
 				  severity);
 	if (!message) {
 		return -1;
@@ -759,15 +717,16 @@ G_MODULE_EXPORT int user_session_logs(user_session_t * c_session,
 	char *severity;
 	char *state_text;
 
-	severity = "low";
 	switch (state) {
 	case SESSION_OPEN:
-		state_text = "User log in";
-		impact = g_strdup_printf("User \"%s\" log in", c_session->user_name);
+		state_text = "User login";
+		severity = "medium";
+		impact = g_strdup_printf("User \"%s\" logged in", c_session->user_name);
 		break;
 	case SESSION_CLOSE:
-		state_text = "User log out";
-		impact = g_strdup_printf("User \"%s\" log out", c_session->user_name);
+		state_text = "User logout";
+		severity = "low";
+		impact = g_strdup_printf("User \"%s\" logged out", c_session->user_name);
 		break;
 	default:
 		return -1;
@@ -785,8 +744,7 @@ G_MODULE_EXPORT int user_session_logs(user_session_t * c_session,
 	}
 
 	/* feed message fields */
-	message =
-	    create_message_session(tpl, c_session, state_text, impact,
+	message = create_message_session(tpl, c_session, state_text, impact,
 				   severity);
 	g_free(impact);
 	if (!message) {
@@ -877,16 +835,18 @@ G_MODULE_EXPORT void auth_error_log(user_session_t * session,
 	tpl = g_private_get(params->autherr_tpl);
 	if (!tpl) {
 		tpl = create_autherr_template();
-		if (!tpl)
+		if (!tpl) {
 			return;
+		}
 		g_private_set(params->autherr_tpl, tpl);
 	}
 
 	/* feed message fields */
-	if (error == AUTH_ERROR_CREDENTIALS)
+	if (error == AUTH_ERROR_CREDENTIALS) {
 		severity = "high";
-	else
+	} else {
 		severity = "medium";
+	}
 	message = create_message_autherr(tpl, session, text, severity);
 	if (!message) {
 		return;
