@@ -2,7 +2,7 @@
  ** Copyright(C) 2003 Eric Leblond <eric@regit.org>
  **		     Vincent Deffontaines <vincent@gryzor.com>
  **
- ** $Id: syslog.c 3618 2007-08-10 06:32:17Z regit $
+ ** $Id: syslog.c 3770 2007-09-25 23:15:22Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -85,10 +85,8 @@ G_MODULE_EXPORT gint user_packet_logs(void *element, tcp_state_t state,
 		const connection_t *connection = element;
 
 		/* convert IP source and destination addresses to string */
-		format_ipv6(&connection->tracking.saddr,
-			source_addr, sizeof(source_addr));
-		format_ipv6(&connection->tracking.daddr,
-			dest_addr, sizeof(dest_addr));
+		FORMAT_IPV6(&connection->tracking.saddr, source_addr);
+		FORMAT_IPV6(&connection->tracking.daddr, dest_addr);
 
 		if (connection->log_prefix) {
 			log_prefix =
@@ -125,10 +123,8 @@ G_MODULE_EXPORT gint user_packet_logs(void *element, tcp_state_t state,
 		struct accounted_connection *connection = element;
 
 		/* convert IP source and destination addresses to string */
-		format_ipv6(&connection->tracking.saddr,
-			source_addr, sizeof(source_addr));
-		format_ipv6(&connection->tracking.daddr,
-			dest_addr, sizeof(dest_addr));
+		FORMAT_IPV6(&connection->tracking.saddr, source_addr);
+		FORMAT_IPV6(&connection->tracking.daddr, dest_addr);
 
 		saddr = dest_addr;
 		daddr = source_addr;
@@ -174,7 +170,7 @@ G_MODULE_EXPORT int user_session_logs(user_session_t * c_session,
 	char *prefix = "[nuauth] ";
 	char address[INET6_ADDRSTRLEN];
 
-	format_ipv6(&c_session->addr, address, sizeof(address));
+	format_ipv6(&c_session->addr, address, sizeof(address), NULL);
 	switch (state) {
 	case SESSION_OPEN:
 		g_message("%sUser %s connect on %s", prefix,
@@ -191,7 +187,7 @@ G_MODULE_EXPORT int user_session_logs(user_session_t * c_session,
 G_MODULE_EXPORT gboolean init_module_from_conf(module_t * module)
 {
 	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-		    "Log_syslog module ($Revision: 3618 $)");
+		    "Log_syslog module ($Revision: 3770 $)");
 	return TRUE;
 }
 
@@ -205,7 +201,7 @@ G_MODULE_EXPORT void auth_error_log(user_session_t * session,
 				    const char *text, gpointer params_ptr)
 {
 	char ipaddr[INET6_ADDRSTRLEN];
-	format_ipv6(&session->addr, ipaddr, sizeof(ipaddr));
+	FORMAT_IPV6(&session->addr, ipaddr);
 
 	g_message("Authentification error: %s", text);
 	g_message("Authentification error: user: %s from %s (port %d), protocol version %d",
