@@ -1,8 +1,9 @@
 /*
  **  "plaintext" module
  ** Copyright(C) 2004-2005 Mikael Berthe <mikael+nufw@lists.lilotux.net>
+ ** Copyright(C) 2005-2008 INL
  **
- ** $Id: plaintext.c 4241 2008-01-07 09:20:15Z haypo $
+ ** $Id: plaintext.c 4650 2008-04-15 11:53:26Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -293,7 +294,7 @@ static int parse_ips(char *ipsline, GSList ** ip_list, char *prefix)
 #endif
 	}
 	g_strfreev(ip_items);
- 	return result;
+	return result;
 }
 
 /**
@@ -320,7 +321,7 @@ static int read_user_list(struct plaintext_params *params)
 
 	if (!fd) {
 		log_message(WARNING, DEBUG_AREA_AUTH,
-			    "read_user_list: fopen error");
+			    "read_user_list: fopen error (%s)", params->plaintext_userfile);
 		return 1;
 	}
 
@@ -442,7 +443,7 @@ static int read_acl_list(struct plaintext_params *params)
 
 	if (!fd) {
 		log_message(FATAL, DEBUG_AREA_MAIN,
-			    "read_acl_list: fopen error");
+			    "read_acl_list: fopen error (%s)", params->plaintext_aclfile);
 		return 1;
 	}
 
@@ -878,7 +879,7 @@ G_MODULE_EXPORT gboolean init_module_from_conf(module_t * module)
 
 
 	log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-		    "Plaintext module ($Revision: 4241 $)");
+		    "Plaintext module ($Revision: 4650 $)");
 	/*  parse conf file */
 	if (module->configfile) {
 		parse_conffile(module->configfile,
@@ -1071,21 +1072,6 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element, gpointer params)
 					"(DBG) skip ACL %s: protocol doesn't match", p_acl->aclname);
 			continue;
 		}
-
-		/*  Check source address */
-		if (!match_ip(p_acl->src_ip, &netdata->saddr)) {
-			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-					"(DBG) skip ACL %s: source IP doesn't match", p_acl->aclname);
-			continue;
-		}
-
-		/*  Check destination address */
-		if (!match_ip(p_acl->dst_ip, &netdata->daddr)) {
-			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-					"(DBG) skip ACL %s: destination IP doesn't match", p_acl->aclname);
-			continue;
-		}
-
 		/*  ICMP? */
 		if (netdata->protocol == IPPROTO_ICMP) {
 			if (p_acl->proto == IPPROTO_ICMP) {
@@ -1106,33 +1092,6 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element, gpointer params)
 				}
 			}
 		} else {
-			/*  Check source port */
-			if (p_acl->src_ports) {
-				int found = 0;
-				struct plaintext_ports *p_ports;
-				GSList *pl_ports = p_acl->src_ports;
-				for (; pl_ports;
-				     pl_ports = g_slist_next(pl_ports)) {
-					p_ports =
-					    (struct plaintext_ports *) pl_ports->
-					    data;
-					if (!p_ports->firstport
-					    ||
-					    ((netdata->source >=
-					      p_ports->firstport)
-					     && (netdata->source <=
-						 p_ports->firstport +
-						 p_ports->nbports))) {
-						found = 1;
-						break;
-					}
-				}
-				if (!found) {
-					debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
-							"(DBG) skip ACL %s: TCP/UDP source port doesn't match", p_acl->aclname);
-					continue;
-				}
-			}
 			/*  Check destination port */
 			if (p_acl->dst_ports) {
 				int found = 0;
@@ -1160,6 +1119,47 @@ G_MODULE_EXPORT GSList *acl_check(connection_t * element, gpointer params)
 					continue;
 				}
 			}
+			/*  Check source port */
+			if (p_acl->src_ports) {
+				int found = 0;
+				struct plaintext_ports *p_ports;
+				GSList *pl_ports = p_acl->src_ports;
+				for (; pl_ports;
+				     pl_ports = g_slist_next(pl_ports)) {
+					p_ports =
+					    (struct plaintext_ports *) pl_ports->
+					    data;
+					if (!p_ports->firstport
+					    ||
+					    ((netdata->source >=
+					      p_ports->firstport)
+					     && (netdata->source <=
+						 p_ports->firstport +
+						 p_ports->nbports))) {
+						found = 1;
+						break;
+					}
+				}
+				if (!found) {
+					debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
+							"(DBG) skip ACL %s: TCP/UDP source port doesn't match", p_acl->aclname);
+					continue;
+				}
+			}
+		}
+
+		/*  Check source address */
+		if (!match_ip(p_acl->src_ip, &netdata->saddr)) {
+			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
+					"(DBG) skip ACL %s: source IP doesn't match", p_acl->aclname);
+			continue;
+		}
+
+		/*  Check destination address */
+		if (!match_ip(p_acl->dst_ip, &netdata->daddr)) {
+			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_MAIN,
+					"(DBG) skip ACL %s: destination IP doesn't match", p_acl->aclname);
+			continue;
 		}
 
 		/*  O.S. filtering? */
