@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2005-2007 INL
+ ** Copyright(C) 2005-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **
- ** $Id: nuauthconf.c 4164 2007-12-21 10:32:35Z toady $
+ ** $Id: nuauthconf.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -327,75 +327,75 @@ static gboolean compare_nuauthparams(
 {
 	gboolean restart = FALSE;
 	if (strcmp(current->authreq_port, new->authreq_port) != 0) {
-		g_warning("authreq_port has changed, please restart");
+		g_warning("authreq_port has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (strcmp(current->userpckt_port, new->userpckt_port) != 0) {
-		g_warning("userpckt_port has changed, please restart");
+		g_warning("userpckt_port has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->log_users_sync != new->log_users_sync) {
-		g_warning("log_users_sync has changed, please restart");
+		g_warning("log_users_sync has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->log_users_strict != new->log_users_strict) {
-		g_warning("log_users_strict has changed, please restart");
+		g_warning("log_users_strict has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->push != new->push) {
 		g_warning
-		    ("switch between push and poll mode has been asked, please restart");
+		    ("switch between push and poll mode has been asked, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->acl_cache != new->acl_cache) {
 		g_warning
-		    ("switch between acl caching or not has been asked, please restart");
+		    ("acl caching has been switched on/off, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->user_cache != new->user_cache) {
 		g_warning
-		    ("switch between user caching or not has been asked, please restart");
+		    ("switch between user caching or not has been asked, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->hello_authentication != new->hello_authentication) {
 		g_warning
-		    ("switch on ip authentication feature has been asked, please restart");
+		    ("switch on ip authentication feature has been asked, restart needed");
 		restart = TRUE;
 	}
 
 	if (strcmp(current->nufw_srv, new->nufw_srv) != 0) {
-		g_warning("nufw listening ip has changed, please restart");
+		g_warning("nufw listening ip has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (strcmp(current->client_srv, new->client_srv) != 0) {
 		g_warning
-		    ("client listening ip has changed, please restart");
+		    ("client listening ip has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->nufw_has_conntrack != new->nufw_has_conntrack) {
 		g_warning
-		    ("nufw conntrack mode has changed, please restart");
+		    ("nufw conntrack mode has changed, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->use_command_server != new->use_command_server) {
 		g_warning
-		    ("command server option has been modified, please restart");
+		    ("command server option has been modified, restart needed");
 		restart = TRUE;
 	}
 
 	if (current->do_ip_authentication != new->do_ip_authentication) {
 		g_warning
-		    ("nuauth_do_ip_authentication has been modified, please restart");
+		    ("nuauth_do_ip_authentication has been modified, restart needed");
 		restart = TRUE;
 	}
 	return restart;
