@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2007 INL
+ ** Copyright(C) 2007-2008 INL
  ** Written by Victor Stinner <victor.stinner@inl.fr>
  **
- ** $Id: nuthread.c 3758 2007-09-24 20:32:45Z regit $
+ ** $Id: nuthread.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -93,11 +93,11 @@ void thread_wait_end(struct nuauth_thread_t *thread)
 	GThread *self;
 	if (!thread->valid)
 		return;
-	log_message(DEBUG, DEBUG_AREA_MAIN, "Wait end of thread '%s'", thread->name);
+	log_message(DEBUG, DEBUG_AREA_MAIN, "Waiting for end of thread '%s'", thread->name);
 	self = g_thread_self();
 	if (self == thread->thread) {
 		log_message(INFO, DEBUG_AREA_MAIN,
-			    "Information: Avoid deadlock: don't wait end of active thread!");
+			    "Information : Avoiding thread deadlock : not waiting for the end of myself!");
 		return;
 	}
 	g_thread_join(thread->thread);
