@@ -2,7 +2,7 @@
  ** Copyright(C) 2007 INL
  ** Written by Victor Stinner <victor.stinner@inl.fr>
  **
- ** $Id: nuthread.h 3057 2007-03-26 16:28:48Z haypo $
+ ** $Id: nuthread.h 3758 2007-09-24 20:32:45Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -26,14 +26,22 @@ struct nuauth_thread_t {
 	GThread *thread;
 	GMutex *mutex;
 	const char *name;
+	gpointer data;
 };
 
 void thread_new(struct nuauth_thread_t *thread,
 		const char* name,
 		void *(*func) (GMutex *));
+void thread_new_wdata(struct nuauth_thread_t *thread,
+		const char* name,
+		gpointer data,
+		void *(*func) (struct nuauth_thread_t *));
 void thread_stop(struct nuauth_thread_t *thread);
+void thread_list_stop(GSList *thread_list);
 void thread_wait_end(struct nuauth_thread_t *thread);
+void thread_list_wait_end(GSList *thread_list);
 void thread_destroy(struct nuauth_thread_t *thread);
+void thread_list_destroy(GSList *thread_list);
 
 #endif
 
