@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2003-2006 Eric Leblond <regit@inl.fr>
+ ** Copyright(C) 2003-2008 Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: pckt_authsrv.c 4015 2007-12-04 15:22:47Z regit $
+ ** $Id: pckt_authsrv.c 4601 2008-04-02 20:22:38Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -48,7 +48,7 @@ nu_error_t parse_dgram(connection_t * connection, unsigned char *dgram,
 	/* get ip headers till tracking is filled */
 	ip_hdr_size =
 	    get_ip_headers(&connection->tracking, dgram, dgram_size);
-	
+
 	if (ip_hdr_size == 0) {
 		log_message(WARNING, DEBUG_AREA_PACKET | DEBUG_AREA_GW,
 			    "Can't parse IP headers");
@@ -94,7 +94,7 @@ nu_error_t parse_dgram(connection_t * connection, unsigned char *dgram,
 					connection->state =
 					    AUTH_STATE_DONE;
 					log_message(WARNING, DEBUG_AREA_GW,
-						    "nufw sends non SYN TCP packet, ignoring");
+						    "nufw sent a non SYN TCP packet, ignoring");
 					free_connection(connection);
 					return NU_EXIT_NO_RETURN;
 				}
@@ -104,16 +104,17 @@ nu_error_t parse_dgram(connection_t * connection, unsigned char *dgram,
 					connection->state =
 					    AUTH_STATE_DONE;
 					log_message(WARNING, DEBUG_AREA_GW,
-						    "nufw sends SYN ACK TCP packet, ignoring");
+						    "nufw sent a SYN ACK TCP packet, ignoring");
 					free_connection(connection);
 					return NU_EXIT_NO_RETURN;
 				}
 				break;
 			default:
 				log_message(WARNING, DEBUG_AREA_PACKET | DEBUG_AREA_GW,
-					    "Can't parse TCP headers");
+					    "Non-SYN TCP headers, we should not have received this packet");
+				connection->state = AUTH_STATE_DONE;
 				free_connection(connection);
-				return NU_EXIT_ERROR;
+				return NU_EXIT_NO_RETURN;
 			}
 			break;
 		}
@@ -156,11 +157,11 @@ nu_error_t parse_dgram(connection_t * connection, unsigned char *dgram,
 }
 
 #define GET_IFACE_FROM_MSG(conn, msg, iface) \
-    do { if (msg->iface) \
-            { if (msg->iface[0] != '*') \
-	    conn->iface_nfo.iface = g_strndup(msg->iface,IFNAMSIZ); }  \
-        else { conn->iface_nfo.iface = NULL; } \
-    } while (0)
+	do { if (msg->iface) \
+		{ if (msg->iface[0] != '*') \
+		conn->iface_nfo.iface = g_strndup(msg->iface,IFNAMSIZ); }  \
+		else { conn->iface_nfo.iface = NULL; } \
+	} while (0)
 
 /**
  * Parse fields of the message
@@ -291,7 +292,7 @@ nu_error_t authpckt_conntrack(unsigned char *dgram, unsigned int dgram_size)
 	/* Check message content size */
 	if (dgram_size != sizeof(struct nuv4_conntrack_message_t)) {
 		log_message(CRITICAL, DEBUG_AREA_PACKET | DEBUG_AREA_GW,
-				  "Auth conntrack: Improper length of packet (%d instead of %lu)",
+				  "Auth conntrack: Improper length of packet (%d instead of %u)",
 				  dgram_size,
 				  sizeof(struct nuv4_conntrack_message_t));
 		return NU_EXIT_ERROR;
@@ -395,7 +396,7 @@ nu_error_t authpckt_decode(unsigned char **pdgram,
 			if (ret == NU_EXIT_ERROR) {
 				return NU_EXIT_ERROR;
 			}
-			
+
 			if (ntohs(header->msg_length) < dgram_size) {
 				*pdgram_size =
 				    dgram_size - ntohs(header->msg_length);
