@@ -1,8 +1,8 @@
 /*
- ** Copyright(C) 2005-2006 INL
+ ** Copyright(C) 2005-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  **
- ** $Id: sasl.c 4125 2007-12-18 13:19:03Z haypo $
+ ** $Id: sasl.c 4611 2008-04-04 08:32:37Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -277,6 +277,8 @@ nu_error_t get_proto_info(user_session_t * c_session)
 
 			if (FD_ISSET(c_session->socket, &wk_set)) {
 				char buffer[20];
+				memset(buffer, 0, sizeof(buffer));
+
 				debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
 						  "Getting protocol information");
 				ret =
@@ -313,7 +315,7 @@ nu_error_t get_proto_info(user_session_t * c_session)
 					return NU_EXIT_OK;
 				} else {
 					log_message(INFO, DEBUG_AREA_AUTH,
-						    "Error bad proto string");
+						    "Error: bad proto string");
 					return NU_EXIT_ERROR;
 				}
 			}
@@ -460,7 +462,7 @@ static int mysasl_negotiate(user_session_t * c_session, sasl_conn_t * conn)
 		    modules_get_user_groups(c_session->user_name);
 		if (c_session->groups == NULL) {
 			debug_log_message(DEBUG, DEBUG_AREA_AUTH,
-					  "error when searching user groups for %s",
+					  "error when searching groups for user \"%s\"",
 					  c_session->user_name);
 			if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
 				return SASL_FAIL;
@@ -641,10 +643,10 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 			  &count);
 	if (r != SASL_OK) {
 		log_message(WARNING, DEBUG_AREA_AUTH,
-			    "proto v3: generating mechanism list");
+			    "v3 proto: generating mechanism list");
 		return r;
 	}
-	debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH, "proto v3: %d mechanisms : %s",
+	debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH, "v3 proto: %d mechanisms : %s",
 			  count, data);
 	tls_len = sasl_len;
 	/* send capability list to client */
@@ -652,14 +654,14 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 	if ((record_send == GNUTLS_E_INTERRUPTED)
 	    || (record_send == GNUTLS_E_AGAIN)) {
 		debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
-				  "proto v3: sasl nego : need to resend packet");
+				  "v3 proto: sasl nego: need to resend packet");
 		record_send = gnutls_record_send(session, data, tls_len);
 	}
 	if (record_send < 0) {
 		return SASL_FAIL;
 	}
 	debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
-			  "proto v3: Now we know record_send >= 0");
+			  "v3 proto: Now we know record_send >= 0");
 
 	memset(chosenmech, 0, sizeof chosenmech);
 	tls_len =
@@ -667,18 +669,18 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 	if (tls_len <= 0) {
 		if (tls_len == 0) {
 			log_message(INFO, DEBUG_AREA_AUTH,
-				    "proto v3: client didn't choose mechanism");
+				    "v3 proto: client didn't choose mechanism");
 			if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
 				return SASL_FAIL;
 			return SASL_BADPARAM;
 		} else {
 			log_message(INFO, DEBUG_AREA_AUTH,
-				    "proto v3: sasl nego : tls crash");
+				    "v3 proto: sasl nego: tls crash");
 			return SASL_FAIL;
 		}
 	}
 	debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
-			  "proto v3: client chose mechanism %s", chosenmech);
+			  "v3 proto: client chose mechanism %s", chosenmech);
 
 	memset(buf, 0, sizeof buf);
 	tls_len = gnutls_record_recv(session, buf, sizeof(buf));
@@ -687,7 +689,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 			return SASL_FAIL;
 		}
 		debug_log_message(DEBUG, DEBUG_AREA_AUTH,
-				  "proto v3: didn't receive first-sent parameter correctly");
+				  "v3 proto: didn't receive first-sent parameter correctly");
 		if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
 			return SASL_FAIL;
 		return SASL_BADPARAM;
@@ -706,7 +708,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 		r = sasl_server_start(conn, chosenmech, buf, tls_len,
 				      &data, &sasl_len);
 	} else {
-		debug_log_message(DEBUG, DEBUG_AREA_AUTH, "proto v3: start with no msg");
+		debug_log_message(DEBUG, DEBUG_AREA_AUTH, "v3 proto: start with no msg");
 		r = sasl_server_start(conn, chosenmech, NULL, 0, &data,
 				      &sasl_len);
 	}
@@ -714,7 +716,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 	if (r != SASL_OK && r != SASL_CONTINUE) {
 		gchar *user_name = NULL;
 
-		log_message(INFO, DEBUG_AREA_AUTH, "proto v3: sasl negotiation error: %d",
+		log_message(INFO, DEBUG_AREA_AUTH, "v3 proto: sasl negotiation error: %d",
 			    r);
 		ret =
 		    sasl_getprop(conn, SASL_USERNAME,
@@ -751,10 +753,10 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 #ifdef DEBUG_ENABLE
 			if (!tls_len) {
 				log_message(VERBOSE_DEBUG, DEBUG_AREA_USER | DEBUG_AREA_AUTH,
-					    "proto v3: Client disconnected during sasl negotiation");
+					    "v3 proto: Client disconnected during sasl negotiation");
 			} else {
 				log_message(VERBOSE_DEBUG, DEBUG_AREA_USER | DEBUG_AREA_AUTH,
-					    "proto v3: TLS error during sasl negotiation");
+					    "v3 proto: TLS error during sasl negotiation");
 			}
 #endif
 			return SASL_FAIL;
@@ -764,7 +766,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 		if (r != SASL_OK && r != SASL_CONTINUE) {
 #ifdef DEBUG_ENABLE
 			log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
-				    "proto v3: error performing SASL negotiation: %s",
+				    "v3 proto: error performing SASL negotiation: %s",
 				    sasl_errdetail(conn));
 #endif
 			if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
@@ -776,7 +778,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 
 	if (r != SASL_OK) {
 		debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_AUTH,
-				  "proto v3: incorrect authentication");
+				  "v3 proto: incorrect authentication");
 		if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
 			return SASL_FAIL;
 		return SASL_BADAUTH;
@@ -792,7 +794,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 		    sasl_getprop(conn, SASL_USERNAME,
 				 (const void **) &(tempname));
 		if (ret != SASL_OK) {
-			g_warning("proto v3: get user failed");
+			g_warning("v3 proto: get user failed");
 			return ret;
 		} else {
 			c_session->user_name = g_strdup(tempname);
@@ -804,7 +806,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 		    modules_get_user_groups(c_session->user_name);
 		if (c_session->groups == NULL) {
 			debug_log_message(DEBUG, DEBUG_AREA_USER | DEBUG_AREA_AUTH,
-					  "proto v3: Couldn't get user groups");
+					  "v3 proto: Couldn't get user groups");
 			if (gnutls_record_send(session, "N", 1) <= 0)	/* send NO to client */
 				return SASL_FAIL;
 			return SASL_BADAUTH;
@@ -813,7 +815,7 @@ static int mysasl_negotiate_v3(user_session_t * c_session,
 		    modules_get_user_id(c_session->user_name);
 		if (c_session->user_id == 0) {
 			log_message(INFO, DEBUG_AREA_USER | DEBUG_AREA_AUTH,
-				    "proto v3: Couldn't get user ID!");
+				    "v3 proto: Couldn't get user ID!");
 		}
 	}
 
