@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2006,2007 INL
+ ** Copyright(C) 2006-2008 INL
  ** Written by Eric Leblond <regit@inl.fr>
  ** INL : http://www.inl.fr/
  **
- ** $Id: take_decision.c 3803 2007-10-09 13:42:13Z regit $
+ ** $Id: take_decision.c 4610 2008-04-04 08:14:45Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -401,7 +401,7 @@ void send_auth_response(gpointer packet_id_ptr, gpointer userdata)
 			/* check if user id fit in 16 bits */
 			if (0xFFFF < element->mark) {
 				log_message(WARNING, DEBUG_AREA_MAIN,
-					    "Mark don't fit in 16 bits, not to truncate the value.");
+					    "Mark bigger than 16 bits, need to truncate the value.");
 			}
 			mark16 = (element->mark & 0xFFFF);
 			if (element->decision == DECISION_REJECT) {
