@@ -3,7 +3,7 @@
  ** Written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <gryzor@inl.fr>
  **
- ** $Id: tls.c 4277 2008-01-08 17:24:47Z lds $
+ ** $Id: tls.c 4633 2008-04-06 13:21:16Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -98,7 +98,7 @@ gint check_certs_for_tls_session(gnutls_session session)
 
 		if (status & GNUTLS_CERT_REVOKED) {
 			g_warning("The certificate has been revoked.");
-	
+
 			return SASL_EXPIRED;
 		}
 
@@ -135,7 +135,7 @@ gint check_certs_for_tls_session(gnutls_session session)
 		SECURE_STRNCAT(buffer, ", server certificate not yet activated", sizeof(buffer));
 		g_warning("TLS: Invalid certificates received from nuauth server:%s",
 			  buffer);
-		return SASL_FAIL;    
+		return SASL_FAIL;
 	}
 	if (gnutls_certificate_expiration_time_peers(session) < now) {
 		char buffer[200];
@@ -144,7 +144,7 @@ gint check_certs_for_tls_session(gnutls_session session)
 		SECURE_STRNCAT(buffer, ", server certificate expired", sizeof(buffer));
 		g_warning("TLS: Invalid certificates received from nuauth server:%s",
 			  buffer);
-		return SASL_FAIL;    
+		return SASL_FAIL;
 	}
 
 
@@ -221,7 +221,7 @@ static int generate_dh_params(gnutls_dh_params * dh_params)
 }
 
 /**
- * Refresh crl file 
+ * Refresh crl file
  *
  * This function is run periodically because it is pushed with
  * cleanup_func_push() to the list of nuauth periodically run
@@ -240,13 +240,12 @@ void refresh_crl_file()
 							     x509_cred,
 							     nuauth_tls.crl_file,
 							     GNUTLS_X509_FMT_PEM);
-			if(ret < 0)
-			{
+			if (ret < 0) {
 				log_message(INFO, DEBUG_AREA_PERF,
 						"[%i] NuFW TLS: CRL file reloading failed (%s)",
 						getpid(), gnutls_strerror(ret));
 			}
-				
+			nuauth_tls.crl_file_mtime = stats.st_mtime;
 		}
 		nuauth_tls.crl_refresh_counter = 0;
 	}
@@ -359,7 +358,7 @@ int tls_connect(int socket_fd, gnutls_session ** session_ptr)
 		}
 	} else {
 		debug_log_message(DEBUG, DEBUG_AREA_GW | DEBUG_AREA_USER,
-				  "Certificate verification is not done as requested");
+				  "Certificate verification is not done, as specified in configuration");
 	}
 
 	return SASL_OK;
@@ -372,12 +371,12 @@ int check_key_perms(const char* filename)
 	if (stat(filename, &infos) != 0) {
 		return 0;
 	}
-	
+
 	/* Check it's owned by the current user */
 	if (infos.st_mode & S_IRGRP || infos.st_mode & S_IROTH) {
 		return 0;
 	}
-	
+
 	return 1;
 }
 
@@ -395,15 +394,11 @@ int create_x509_credentials()
 	char *configfile = DEFAULT_CONF_FILE;
 	int ret;
 	confparams_t nuauth_tls_vars[] = {
-		{"nuauth_tls_key", G_TOKEN_STRING, 0,
-		 g_strdup(NUAUTH_KEYFILE)},
-		{"nuauth_tls_cert", G_TOKEN_STRING, 0,
-		 g_strdup(NUAUTH_CERTFILE)},
-		{"nuauth_tls_cacert", G_TOKEN_STRING, 0,
-		 g_strdup(NUAUTH_CACERTFILE)},
+		{"nuauth_tls_key", G_TOKEN_STRING, 0, g_strdup(NUAUTH_KEYFILE)},
+		{"nuauth_tls_cert", G_TOKEN_STRING, 0, g_strdup(NUAUTH_CERTFILE)},
+		{"nuauth_tls_cacert", G_TOKEN_STRING, 0, NULL},
 		{"nuauth_tls_crl", G_TOKEN_STRING, 0, NULL},
-		{"nuauth_tls_crl_refresh", G_TOKEN_INT,
-		 DEFAULT_REFRESH_CRL_INTERVAL, NULL},
+		{"nuauth_tls_crl_refresh", G_TOKEN_INT, DEFAULT_REFRESH_CRL_INTERVAL, NULL},
 		{"nuauth_tls_key_passwd", G_TOKEN_STRING, 0, NULL},
 		{"nuauth_tls_request_cert", G_TOKEN_INT, FALSE, NULL},
 		{"nuauth_tls_auth_by_cert", G_TOKEN_INT, FALSE, NULL}
@@ -420,7 +415,7 @@ int create_x509_credentials()
 
 
 #define READ_CONF(KEY) \
-    get_confvar_value(nuauth_tls_vars, nb_params, KEY)
+	get_confvar_value(nuauth_tls_vars, nb_params, KEY)
 
 	nuauth_tls_key = (char *) READ_CONF("nuauth_tls_key");
 	nuauth_tls_cert = (char *) READ_CONF("nuauth_tls_cert");
@@ -441,7 +436,7 @@ int create_x509_credentials()
 	} else {
 		g_warning("[%i] config : invalid nuauth_tls_auth_by_cert value: %d",
 			getpid(), int_authcert);
-		
+
 		return 0;
 	}
 
@@ -465,7 +460,7 @@ int create_x509_credentials()
 	if (access(nuauth_tls_cert, R_OK)) {
 		g_warning("[%i] TLS : can not access cert file %s",
 			getpid(), nuauth_tls_cert);
-		
+
 		return 0;
 	}
 
@@ -475,8 +470,7 @@ int create_x509_credentials()
 	}
 	nuauth_tls.crl_refresh_counter = 0;
 
-	ret =
-	    gnutls_certificate_allocate_credentials(&nuauth_tls.x509_cred);
+	ret = gnutls_certificate_allocate_credentials(&nuauth_tls.x509_cred);
 	if (ret != 0) {
 		g_warning("[%i] Problem with gnutls_certificate_allocate_credentials() : %s",
 		     getpid(), gnutls_strerror(ret));
@@ -484,23 +478,23 @@ int create_x509_credentials()
 		return 0;
 	}
 
-	ret =
-	    gnutls_certificate_set_x509_trust_file(nuauth_tls.x509_cred,
-						   nuauth_tls_cacert,
-						   GNUTLS_X509_FMT_PEM);
-	if (ret <= 0) {
-		g_warning
-		    ("[%i] Problem with certificate trust file : %s",
-		     getpid(), gnutls_strerror(ret));
+	if (nuauth_tls_cacert != NULL) {
+		ret = gnutls_certificate_set_x509_trust_file(nuauth_tls.x509_cred,
+				nuauth_tls_cacert,
+				GNUTLS_X509_FMT_PEM);
+		if (ret <= 0) {
+			g_warning ("[%i] Problem with certificate authority trust file : %s",
+					getpid(), gnutls_strerror(ret));
 
-		if (nuauth_tls.request_cert == GNUTLS_CERT_REQUIRE
-			|| nuauth_tls.auth_by_cert == MANDATORY_AUTH_BY_CERT)
-			return 0;
+			if (nuauth_tls.request_cert == GNUTLS_CERT_REQUIRE
+					|| nuauth_tls.auth_by_cert == MANDATORY_AUTH_BY_CERT)
+				return 0;
+		}
 	}
-	
+
 	if (!check_key_perms(nuauth_tls_key)) {
-		g_warning("[%i] Private key have too open permissions",
-			getpid());
+		g_warning("[%i] Permissions on private key (%s) are not restrictive enough, it should be readable only by nuauth user.",
+			getpid(), nuauth_tls_key);
 
 		if (nuauth_tls.request_cert == GNUTLS_CERT_REQUIRE
 			|| nuauth_tls.auth_by_cert == MANDATORY_AUTH_BY_CERT) {
@@ -508,8 +502,7 @@ int create_x509_credentials()
 		}
 	}
 
-	ret =
-	    gnutls_certificate_set_x509_key_file(nuauth_tls.x509_cred,
+	ret = gnutls_certificate_set_x509_key_file(nuauth_tls.x509_cred,
 						 nuauth_tls_cert,
 						 nuauth_tls_key,
 						 GNUTLS_X509_FMT_PEM);
@@ -532,6 +525,7 @@ int create_x509_credentials()
 	g_free(nuauth_tls_cacert);
 
 	if (nuauth_tls_crl) {
+		struct stat stats;
 		log_message(VERBOSE_DEBUG, DEBUG_AREA_GW | DEBUG_AREA_USER,
 			    "Certificate revocation list: %s",
 			    nuauth_tls_crl);
@@ -546,6 +540,8 @@ int create_x509_credentials()
 		ret = gnutls_certificate_set_x509_crl_file(nuauth_tls.x509_cred,
 						     nuauth_tls.crl_file,
 						     GNUTLS_X509_FMT_PEM);
+		stat(nuauth_tls.crl_file, &stats);
+		nuauth_tls.crl_file_mtime = stats.st_mtime;
 		if (ret < 0) {
 			g_warning("[%i] Problem with certificate key file : %s",
 				getpid(), gnutls_strerror(ret));
@@ -559,7 +555,7 @@ int create_x509_credentials()
 	if (ret < 0) {
 		g_warning("[%i] Problem generating dh params : %s",
 			getpid(), gnutls_strerror(ret));
-	
+
 		return 0;
 	}
 
