@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2004-2007 INL
+ ** Copyright(C) 2004-2008 INL
  ** Written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <gryzor@inl.fr>
  **
- ** $Id: tls_nufw.c 4125 2007-12-18 13:19:03Z haypo $
+ ** $Id: tls_nufw.c 4633 2008-04-06 13:21:16Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -143,7 +143,7 @@ static int treat_nufw_request(nufw_session_t * c_session)
 			break;
 		case NU_EXIT_NO_RETURN:
 			debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_GW,
-				"Nufw gateway send control message");
+				"Nufw gateway sending control message");
 			break;
 		}
 #if 0
@@ -209,7 +209,7 @@ int tls_nufw_accept(struct tls_nufw_context_t *context)
 	/* initialize TLS */
 	nu_session = g_new0(nufw_session_t, 1);
 	nu_session->connect_timestamp = time(NULL);
-	nu_session->usage = 1;
+	nu_session->usage = 0;
 	nu_session->alive = TRUE;
 	nu_session->peername = addr;
 	nu_session->socket = conn_fd;
@@ -321,7 +321,8 @@ void tls_nufw_main_loop(struct tls_nufw_context_t *context, GMutex * mutex)
 					FD_CLR(c, &context->tls_rx_set);
 					declare_dead_nufw_session(c_session);
 				}
-				release_nufw_session(c_session);
+				else
+					release_nufw_session(c_session);
 			}
 		}
 
@@ -347,7 +348,7 @@ int tls_nufw_init(struct tls_nufw_context_t *context)
 		log_message(FATAL, DEBUG_AREA_GW | DEBUG_AREA_MAIN,
 			    "FATAL ERROR: NuFW bind error: %s", errmsg);
 		log_message(FATAL, DEBUG_AREA_GW | DEBUG_AREA_MAIN,
-			    "Check that nuauth is not running twice. Exit nuauth!");
+			    "Check that nuauth is not running twice. Exiting nuauth!");
 		return 0;
 	}
 #if 0
@@ -417,40 +418,30 @@ void *tls_nufw_authsrv(struct nuauth_thread_t *thread)
 void tls_nufw_start_servers(GSList *servers)
 {
 	char **nufw_servers;
-	int i = 0;
+	int i;
 	/* build servers hash */
 	init_nufw_servers();
 	nuauthdatas->tls_nufw_servers = NULL;
 	/* get raw string from configuration */
 	nufw_servers = g_strsplit(nuauthconf->nufw_srv, " ", 0);
-	while (nufw_servers[i]) {
+	for (i=0; nufw_servers[i]; i++) {
 		/** \todo free context at program exit */
 		struct tls_nufw_context_t *context =
 			g_new0(struct tls_nufw_context_t, 1);
 		struct nuauth_thread_t *srv_thread =
 			g_new0(struct nuauth_thread_t, 1);
-		char **context_datas = g_strsplit(nufw_servers[i], ":", 2);
-		if (context_datas[0]) {
-			context->addr = g_strdup(context_datas[0]);
-		} else {
+		if (!parse_addr_port(nufw_servers[i], nuauthconf->authreq_port, &context->addr, &context->port)) {
 			log_message(FATAL, DEBUG_AREA_MAIN | DEBUG_AREA_GW,
-			    "Address parsing error at %s:%d (%s)", __FILE__,
+			    "Address parsing error at %s:%d (\"%s\")", __FILE__,
 			    __LINE__, nufw_servers[i]);
 			nuauth_ask_exit();
 		}
-		if (context_datas[1]) {
-			context->port = g_strdup(context_datas[1]);
-		} else {
-			context->port = g_strdup(nuauthconf->authreq_port);
-		}
-		g_strfreev(context_datas);
 		thread_new_wdata(srv_thread, "tls nufw server",
 				 (gpointer) context,
 				 tls_nufw_authsrv);
 		/* Append newly created server to list */
 		nuauthdatas->tls_nufw_servers = g_slist_prepend(nuauthdatas->tls_nufw_servers,
 								srv_thread);
-		i++;
 	}
 	g_strfreev(nufw_servers);
 }
