@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2004,2005,2006,2007 INL
+ ** Copyright(C) 2004-2008 INL
  ** Written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <gryzor@inl.fr>
  **
- ** $Id: tls_sasl.c 4125 2007-12-18 13:19:03Z haypo $
+ ** $Id: tls_sasl.c 4633 2008-04-06 13:21:16Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -56,17 +56,17 @@ static void policy_refuse_user(user_session_t * c_session, int c,
 	switch (reason) {
 	case PER_USER_TOO_MANY_LOGINS:
 		log_message(INFO, DEBUG_AREA_USER,
-			    "Policy: User %s already connected too many times, closing socket",
+			    "Policy: Too many opened sessions for user \"%s\", closing socket",
 			    c_session->user_name);
 		break;
 	case PER_IP_TOO_MANY_LOGINS:
 		log_message(INFO, DEBUG_AREA_USER,
-			    "Policy: User %s trying to connect from already overused IP, closing socket",
+			    "Policy: User \"%s\" trying to connect from already overused IP, closing socket",
 			    c_session->user_name);
 		break;
 	default:
 		log_message(WARNING, DEBUG_AREA_USER,
-			    "Policy: User %s has to disconnect for UNKNOWN reason, closing socket",
+			    "Policy (bug!): User \"%s\" has to disconnect for UNKNOWN reason, closing socket",
 			    c_session->user_name);
 	}
 	/* get rid of client */
@@ -210,7 +210,7 @@ void tls_sasl_connect(gpointer userdata, gpointer data)
 			/* parsing complete */
 			if (username) {
 				debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_USER,
-						  "Using username %s from certificate",
+						  "Using username \"%s\" from certificate",
 						  username);
 				c_session->groups =
 				    modules_get_user_groups(username);
