@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2004-2006 INL
+ ** Copyright(C) 2004-2008 INL
  ** Written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <gryzor@inl.fr>
  **
- ** $Id: tls_user.c 4126 2007-12-18 13:20:29Z haypo $
+ ** $Id: tls_user.c 4633 2008-04-06 13:21:16Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -174,7 +174,7 @@ static nu_error_t treat_user_request(user_session_t * c_session)
 #ifdef DEBUG_ENABLE
 		if (datas->buffer_len < 0)
 			log_message(DEBUG, DEBUG_AREA_USER,
-				    "Received error from user %s",
+				    "Received error from user \"%s\"",
 				    c_session->user_name);
 #endif
 		free_buffer_read(datas);
@@ -189,7 +189,7 @@ static nu_error_t treat_user_request(user_session_t * c_session)
 	if (header->proto == PROTO_VERSION
 	    && header->msg_type == USER_HELLO) {
 		debug_log_message(VERBOSE_DEBUG, DEBUG_AREA_USER,
-				  "tls user: HELLO from %s",
+				  "tls user: HELLO from user \"%s\"",
 				  c_session->user_name);
 		free_buffer_read(datas);
 		return NU_EXIT_CONTINUE;
@@ -260,7 +260,7 @@ static nu_error_t treat_user_request(user_session_t * c_session)
 				   NULL);
 	} else {
 		log_message(INFO, DEBUG_AREA_USER,
-			    "Bad packet, option of header is not set or unauthorized option from user %s.",
+			    "Bad packet, option of header is not set or unauthorized option from user \"%s\".",
 			    c_session->user_name);
 		free_buffer_read(datas);
 		return NU_EXIT_OK;
@@ -744,36 +744,27 @@ void *tls_user_authsrv(struct nuauth_thread_t *thread)
 void tls_user_start_servers(GSList *servers)
 {
 	char **user_servers;
-	int i = 0;
+	int i;
 	nuauthdatas->tls_auth_servers = NULL;
 
 	tls_user_servers_init();
 
 	/* get raw string from configuration */
 	user_servers = g_strsplit(nuauthconf->client_srv, " ", 0);
-	while (user_servers[i]) {
+	for (i=0; user_servers[i]; i++) {
 		/** \todo free context at program exit */
-		struct tls_user_context_t *context = 
+		struct tls_user_context_t *context =
 			g_new0(struct tls_user_context_t, 1);
 		struct nuauth_thread_t *srv_thread =
 			g_new0(struct nuauth_thread_t, 1);
-		char **context_datas = g_strsplit(user_servers[i], ":", 2);
-		if (context_datas[0]) {
-			context->addr = g_strdup(context_datas[0]);
-		} else {
+		if (!parse_addr_port(user_servers[i], nuauthconf->userpckt_port, &context->addr, &context->port)) {
 			log_message(FATAL, DEBUG_AREA_MAIN | DEBUG_AREA_GW,
-			    "Address parsing error at %s:%d (%s)", __FILE__,
-			    __LINE__, user_servers[i]);
+					"Address parsing error at %s:%d (\"%s\")", __FILE__,
+					__LINE__, user_servers[i]);
 			nuauth_ask_exit();
 		}
-		if (context_datas[1]) {
-			context->port = g_strdup(context_datas[1]);
-		} else {
-			context->port = g_strdup(nuauthconf->userpckt_port);
-		}
-		g_strfreev(context_datas);
 		log_message(INFO, DEBUG_AREA_MAIN | DEBUG_AREA_USER,
-			    "Creating user socket %s:%s",context->addr, context->port);
+			"Creating user socket %s:%s", context->addr, context->port);
 
 		thread_new_wdata(srv_thread,
 				 "tls auth server",
@@ -782,7 +773,6 @@ void tls_user_start_servers(GSList *servers)
 		/* Append newly created server to list */
 		nuauthdatas->tls_auth_servers = g_slist_prepend(nuauthdatas->tls_auth_servers,
 								srv_thread);
-		i++;
 	}
 	g_strfreev(user_servers);
 }
