@@ -1,9 +1,9 @@
 /*
- ** Copyright(C) 2004-2006 INL http://www.inl.fr/
+ ** Copyright(C) 2004-2008 INL http://www.inl.fr/
  ** Written by  Eric Leblond <regit@inl.fr>
  **             Vincent Deffontaines <vincent@inl.fr>
  **
- ** $Id: user_authsrv.c 4126 2007-12-18 13:20:29Z haypo $
+ ** $Id: user_authsrv.c 4633 2008-04-06 13:21:16Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -87,7 +87,7 @@ void user_check_and_decide(gpointer userdata, gpointer data)
 				char ip_ascii[INET6_ADDRSTRLEN];
 				FORMAT_IPV6(&tlsdata->ip_addr, ip_ascii);
 				g_message
-				    ("User %s on %s tried to authenticate packet from other ip",
+				    ("User \"%s\" on %s tried to authenticate packet from other ip",
 				     conn_elt->username, ip_ascii);
 				conn_elt->log_prefix = g_strdup(SPOOFED_LOG_PREFIX);
 				print_connection(conn_elt, "User spoofed Packet");
