@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@gryzor.com>
  ** INL http://www.inl.fr/
  **
- ** $Id: audit.c 4122 2007-12-18 13:10:36Z haypo $
+ ** $Id: audit.c 4581 2008-03-21 21:16:56Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -74,46 +74,3 @@ void process_usr2(int signum)
 	log_printf(DEBUG_LEVEL_FATAL, "USR2: Setting debug level to %d",
 		   debug_level);
 }
-
-#ifdef HAVE_LIBCONNTRACK
-/**
- * Remove -M : set nufw_conntrack_uses_mark to 0
- */
-
-void process_sys(int signum)
-{
-	if (handle_conntrack_event != 0) {
-		handle_conntrack_event = 0;
-		log_printf(DEBUG_LEVEL_INFO,
-			   "SYS:   Setting handle_conntrack_event level to 0 (this cancels the -C switch)",
-			   debug_level);
-	} else {
-	  log_printf(DEBUG_LEVEL_INFO,
-		     "SYS:   doing nothing (handle_conntrack_event is already zeroed)",
-		     debug_level);
-	}
-}
-
-/**
- * Reset -M : set nufw_conntrack_uses_mark to 1
- */
-void process_winch(int signum)
-{
-	if (handle_conntrack_event == 0) {
-		handle_conntrack_event = 1;
-		if (pthread_create(&(tls.conntrack_event_handler),
-				   NULL,
-				   conntrack_event_handler,
-				   NULL) == EAGAIN) {
-			exit(EXIT_FAILURE);
-		}
-		log_printf(DEBUG_LEVEL_INFO,
-			   "WINCH: Setting handle_conntrack_event level to 1 (this activates the -C switch)",
-			   debug_level);
-	} else {
-		log_printf(DEBUG_LEVEL_INFO,
-			   "WINCH: doing nothing (handle_conntrack_event already set)",
-			   debug_level);
-	}
-}
-#endif
