@@ -1,10 +1,10 @@
 /*
- ** Copyright (C) 2002-2006 INL
+ ** Copyright (C) 2002-2008 INL
  ** Written by ric Leblond <eric@regit.org>
  **            Vincent Deffontaines <vincent@gryzor.com>
  ** INL http://www.inl.fr/
  **
- ** $Id: authsrv.c 4242 2008-01-07 09:25:28Z regit $
+ ** $Id: authsrv.c 4338 2008-01-19 15:17:07Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -101,12 +101,12 @@ int auth_process_answer(char *dgram, int dgram_size)
 	case DECISION_REJECT:
 		/* Packet is rejected, ie. dropped and ICMP signalized */
 		log_area_printf(DEBUG_AREA_PACKET, DEBUG_LEVEL_VERBOSE_DEBUG,
-				"(*) Rejecting %lu", packet_id);
+				"(*) Rejecting %" PRIu32, packet_id);
 		IPQ_SET_VERDICT(packet_id, NF_DROP);
 		if (send_icmp_unreach(dgram +
 				  sizeof(nuv4_nuauth_decision_response_t)) == -1) {
 			log_area_printf(DEBUG_AREA_PACKET, DEBUG_LEVEL_WARNING,
-					"(*) Could not sent ICMP reject for %lu", packet_id);
+					"(*) Could not sent ICMP reject for %" PRIu32, packet_id);
 		}
 		break;
 
