@@ -3,7 +3,7 @@
  ** Written by Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: conntrack.c 4122 2007-12-18 13:10:36Z haypo $
+ ** $Id: conntrack.c 4594 2008-03-31 15:33:56Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -25,7 +25,7 @@
  * Connection tracking function if NuFW is compiled with \#HAVE_LIBCONNTRACK.
  */
 
-#define DEBUG_CONNTRACK
+#undef DEBUG_CONNTRACK
 
 #include "nufw.h"
 #include "ipv6.h"
