@@ -3,7 +3,7 @@
  ** Written by Eric Leblond <regit@inl.fr>
  ** INL http://www.inl.fr/
  **
- ** $Id: iface.h 2920 2007-03-09 14:17:27Z regit $
+ ** $Id: iface.h 4312 2008-01-15 08:51:45Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -22,7 +22,7 @@
 #ifndef IFACE_H
 #define IFACE_H
 
-#ifdef HAVE_NLIF_CATCH
+#ifdef HAVE_NFQ_INDEV_NAME
 int get_interface_information(struct nlif_handle *inst,
 			      struct queued_pckt *q_pckt,
 			      struct nfq_data *nfad);
