@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@gryzor.com>
  ** INL http://www.inl.fr/
  **
- ** $Id: main.c 4210 2008-01-02 17:13:51Z toady $
+ ** $Id: main.c 4581 2008-03-21 21:16:56Z regit $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -267,26 +267,6 @@ void install_signals()
 		log_area_printf(DEBUG_AREA_MAIN, DEBUG_LEVEL_WARNING,
 				"Warning: Could not set signal POLL");
 	}
-
-#ifdef HAVE_LIBCONNTRACK
-	/* intercpet SIGSYS */
-	memset(&action, 0, sizeof(action));
-	action.sa_handler = &process_sys;
-	action.sa_flags = SIGSYS;
-	if (sigaction(SIGSYS, &action, NULL) == -1) {
-		log_area_printf(DEBUG_AREA_MAIN, DEBUG_LEVEL_WARNING,
-				"Warning: Could not set signal SYS");
-	}
-
-	/* intercpet SIGWINCH */
-	memset(&action, 0, sizeof(action));
-	action.sa_handler = &process_winch;
-	action.sa_flags = SIGWINCH;
-	if (sigaction(SIGWINCH, &action, NULL) == -1) {
-		log_area_printf(DEBUG_AREA_MAIN, DEBUG_LEVEL_WARNING,
-				"Warning: Could not set signal WINCH");
-	}
-#endif
 }
 
 /**
@@ -619,6 +599,9 @@ int main(int argc, char *argv[])
 		exit(EXIT_FAILURE);
 	}
 
+	/* Nice nufw to increase performance of nfnetlink layer */
+	nice(-1);
+
 	/* Daemon code */
 	if (daemonize == 1) {
 		nufw_daemonize();
