@@ -3,7 +3,7 @@
 ** Written by ric Leblond <regit@inl.fr>
 ** INL http://www.inl.fr/
 **
-** $Id: structure.h 2918 2007-03-09 10:04:02Z haypo $
+** $Id: structure.h 4203 2008-01-02 15:34:33Z regit $
 **
 ** This program is free software; you can redistribute it and/or modify
 ** it under the terms of the GNU General Public License as published by
@@ -76,6 +76,9 @@ int track_size;
 /*! If equals to 1, set mark on packet using #IPQ_SET_VWMARK. Default value: 0 */
 int nufw_set_mark;
 
+/*! If equals to 1, do a strict check of all TLS property */
+int nufw_strict_tls;
+
 /**
  * This enum is used to code the state of  a packet
  * with respect to nufw nuauth interaction
