@@ -4,7 +4,7 @@
  **            Vincent Deffontaines <vincent@gryzor.com>
  ** INL http://www.inl.fr/
  **
- ** $Id: tls.c 4277 2008-01-08 17:24:47Z lds $
+ ** $Id: tls.c 4544 2008-03-06 12:51:03Z gryzor $
  **
  ** This program is free software; you can redistribute it and/or modify
  ** it under the terms of the GNU General Public License as published by
@@ -43,7 +43,7 @@ extern gnutls_session *tls_connect(void);
 
 
 /**
- * Perform certificate checks: Logs for each check and 
+ * Perform certificate checks: Logs for each check and
  * return the global check result.
  *
  * Returns 1 on error, 0 on success.
@@ -68,7 +68,7 @@ unsigned int tls_cert_verify(gnutls_session *tls_session, char *nuauth_cert_dn)
 		char buffer[200];
 
 		buffer[0] = 0;
-		if (status & GNUTLS_CERT_INVALID) 
+		if (status & GNUTLS_CERT_INVALID)
 			SECURE_STRNCAT(buffer, " invalid.", sizeof(buffer));
 		if (status & GNUTLS_CERT_REVOKED)
 			SECURE_STRNCAT(buffer, " revoked.", sizeof(buffer));
@@ -96,7 +96,7 @@ unsigned int tls_cert_verify(gnutls_session *tls_session, char *nuauth_cert_dn)
 		log_area_printf(DEBUG_AREA_GW, DEBUG_LEVEL_WARNING,
 				"TLS: Invalid certificates received from nuauth server:%s",
 				buffer);
-		return 1;    
+		return 1;
 	}
 	if (gnutls_certificate_expiration_time_peers(*tls_session) < now) {
 		char buffer[200];
@@ -106,11 +106,11 @@ unsigned int tls_cert_verify(gnutls_session *tls_session, char *nuauth_cert_dn)
 		log_area_printf(DEBUG_AREA_GW, DEBUG_LEVEL_WARNING,
 				"TLS: Invalid certificates received from nuauth server:%s",
 				buffer);
-		return 1;    
+		return 1;
 	}
 
 	if (nuauth_cert_dn) {
-		if (!check_nuauth_cert_dn(tls_session)) 
+		if (!check_nuauth_cert_dn(tls_session))
 			return 1;
 	}
 
@@ -222,12 +222,12 @@ int check_key_perms(const char* filename)
 	if (stat(filename, &infos) != 0) {
 		return 0;
 	}
-	
+
 	/* Check it's owned by the current user */
 	if (infos.st_mode & S_IRGRP || infos.st_mode & S_IROTH) {
 		return 0;
 	}
-	
+
 	return 1;
 }
 
@@ -296,7 +296,7 @@ gnutls_session *tls_connect()
 	if (!check_key_perms(key_file)) {
 		log_area_printf(DEBUG_AREA_MAIN,
 				DEBUG_LEVEL_FATAL,
-				"Private key have too open permissions");
+				"Private key has too open permissions");
 		if (ca_file || nufw_strict_tls) {
 			return NULL;
 		}
